from .resources import *
from .endpoints import *

# Type exports for better discoverability
# Generated type exports
# These types are automatically exported for better IDE support

# Type classes
# ApiKeysCreateBody
# ApiKeysCreateOutput
# ApiKeysGetOutput
# ApiKeysListOutput
# ApiKeysListQuery
# ApiKeysRevealOutput
# ApiKeysRevokeOutput
# ApiKeysRotateBody
# ApiKeysRotateOutput
# ApiKeysUpdateBody
# ApiKeysUpdateOutput
# DashboardBootBody
# DashboardBootOutput
# DashboardInstanceCallbacksCreateBody
# DashboardInstanceCallbacksCreateOutput
# DashboardInstanceCallbacksDeleteOutput
# DashboardInstanceCallbacksDestinationsCreateBody
# DashboardInstanceCallbacksDestinationsCreateOutput
# DashboardInstanceCallbacksDestinationsDeleteOutput
# DashboardInstanceCallbacksDestinationsGetOutput
# DashboardInstanceCallbacksDestinationsListOutput
# DashboardInstanceCallbacksDestinationsListQuery
# DashboardInstanceCallbacksDestinationsUpdateBody
# DashboardInstanceCallbacksDestinationsUpdateOutput
# DashboardInstanceCallbacksEventsGetOutput
# DashboardInstanceCallbacksEventsListOutput
# DashboardInstanceCallbacksEventsListQuery
# DashboardInstanceCallbacksGetOutput
# DashboardInstanceCallbacksInstancesCreateBody
# DashboardInstanceCallbacksInstancesCreateOutput
# DashboardInstanceCallbacksInstancesDeleteOutput
# DashboardInstanceCallbacksInstancesListOutput
# DashboardInstanceCallbacksInstancesListQuery
# DashboardInstanceCallbacksListOutput
# DashboardInstanceCallbacksListQuery
# DashboardInstanceCallbacksNotificationsGetOutput
# DashboardInstanceCallbacksNotificationsListOutput
# DashboardInstanceCallbacksNotificationsListQuery
# DashboardInstanceCallbacksUpdateBody
# DashboardInstanceCallbacksUpdateOutput
# DashboardInstanceCustomProvidersCodeGetCodeEditorTokenOutput
# DashboardInstanceCustomProvidersCommitsCreateBody
# DashboardInstanceCustomProvidersCommitsCreateOutput
# DashboardInstanceCustomProvidersCommitsGetOutput
# DashboardInstanceCustomProvidersCommitsListOutput
# DashboardInstanceCustomProvidersCommitsListQuery
# DashboardInstanceCustomProvidersCreateBody
# DashboardInstanceCustomProvidersCreateOutput
# DashboardInstanceCustomProvidersDeploymentsGetLogsOutput
# DashboardInstanceCustomProvidersDeploymentsGetOutput
# DashboardInstanceCustomProvidersDeploymentsListOutput
# DashboardInstanceCustomProvidersDeploymentsListQuery
# DashboardInstanceCustomProvidersEnvironmentsGetOutput
# DashboardInstanceCustomProvidersEnvironmentsListOutput
# DashboardInstanceCustomProvidersEnvironmentsListQuery
# DashboardInstanceCustomProvidersGetOutput
# DashboardInstanceCustomProvidersListOutput
# DashboardInstanceCustomProvidersListQuery
# DashboardInstanceCustomProvidersUpdateBody
# DashboardInstanceCustomProvidersUpdateOutput
# DashboardInstanceCustomProvidersVersionsCreateBody
# DashboardInstanceCustomProvidersVersionsCreateOutput
# DashboardInstanceCustomProvidersVersionsGetOutput
# DashboardInstanceCustomProvidersVersionsListOutput
# DashboardInstanceCustomProvidersVersionsListQuery
# DashboardInstanceFileLinksCreateBody
# DashboardInstanceFileLinksCreateOutput
# DashboardInstanceFileLinksDeleteOutput
# DashboardInstanceFileLinksGetOutput
# DashboardInstanceFileLinksListOutput
# DashboardInstanceFileLinksListQuery
# DashboardInstanceFilesDeleteOutput
# DashboardInstanceFilesGetOutput
# DashboardInstanceFilesListOutput
# DashboardInstanceFilesListQuery
# DashboardInstanceIdentitiesCreateBody
# DashboardInstanceIdentitiesCreateOutput
# DashboardInstanceIdentitiesCredentialsCreateBody
# DashboardInstanceIdentitiesCredentialsCreateOutput
# DashboardInstanceIdentitiesCredentialsDeleteOutput
# DashboardInstanceIdentitiesCredentialsGetOutput
# DashboardInstanceIdentitiesCredentialsListOutput
# DashboardInstanceIdentitiesCredentialsListQuery
# DashboardInstanceIdentitiesCredentialsUpdateBody
# DashboardInstanceIdentitiesCredentialsUpdateOutput
# DashboardInstanceIdentitiesDelegationConfigsCreateBody
# DashboardInstanceIdentitiesDelegationConfigsCreateOutput
# DashboardInstanceIdentitiesDelegationConfigsDeleteOutput
# DashboardInstanceIdentitiesDelegationConfigsGetOutput
# DashboardInstanceIdentitiesDelegationConfigsListOutput
# DashboardInstanceIdentitiesDelegationConfigsListQuery
# DashboardInstanceIdentitiesDelegationConfigsUpdateBody
# DashboardInstanceIdentitiesDelegationConfigsUpdateOutput
# DashboardInstanceIdentitiesDelegationRequestsApproveOutput
# DashboardInstanceIdentitiesDelegationRequestsApproveQuery
# DashboardInstanceIdentitiesDelegationRequestsCreateBody
# DashboardInstanceIdentitiesDelegationRequestsCreateOutput
# DashboardInstanceIdentitiesDelegationRequestsDenyOutput
# DashboardInstanceIdentitiesDelegationRequestsDenyQuery
# DashboardInstanceIdentitiesDelegationRequestsGetOutput
# DashboardInstanceIdentitiesDelegationRequestsGetQuery
# DashboardInstanceIdentitiesDelegationRequestsListOutput
# DashboardInstanceIdentitiesDelegationRequestsListQuery
# DashboardInstanceIdentitiesDelegationsCreateBody
# DashboardInstanceIdentitiesDelegationsCreateOutput
# DashboardInstanceIdentitiesDelegationsGetOutput
# DashboardInstanceIdentitiesDelegationsListOutput
# DashboardInstanceIdentitiesDelegationsListQuery
# DashboardInstanceIdentitiesDelegationsRevokeOutput
# DashboardInstanceIdentitiesDeleteOutput
# DashboardInstanceIdentitiesGetOutput
# DashboardInstanceIdentitiesListOutput
# DashboardInstanceIdentitiesListQuery
# DashboardInstanceIdentitiesUpdateBody
# DashboardInstanceIdentitiesUpdateOutput
# DashboardInstanceIdentityActorsCreateBody
# DashboardInstanceIdentityActorsCreateOutput
# DashboardInstanceIdentityActorsDeleteOutput
# DashboardInstanceIdentityActorsGetOutput
# DashboardInstanceIdentityActorsListOutput
# DashboardInstanceIdentityActorsListQuery
# DashboardInstanceIdentityActorsUpdateBody
# DashboardInstanceIdentityActorsUpdateOutput
# DashboardInstanceMagicMcpGroupsAddServersBody
# DashboardInstanceMagicMcpGroupsAddServersOutput
# DashboardInstanceMagicMcpGroupsCreateBody
# DashboardInstanceMagicMcpGroupsCreateOutput
# DashboardInstanceMagicMcpGroupsDeleteOutput
# DashboardInstanceMagicMcpGroupsGetOutput
# DashboardInstanceMagicMcpGroupsListOutput
# DashboardInstanceMagicMcpGroupsListQuery
# DashboardInstanceMagicMcpGroupsRemoveServersBody
# DashboardInstanceMagicMcpGroupsRemoveServersOutput
# DashboardInstanceMagicMcpGroupsUpdateBody
# DashboardInstanceMagicMcpGroupsUpdateOutput
# DashboardInstanceMagicMcpServersCreateBody
# DashboardInstanceMagicMcpServersCreateOutput
# DashboardInstanceMagicMcpServersDeleteOutput
# DashboardInstanceMagicMcpServersGetOutput
# DashboardInstanceMagicMcpServersListOutput
# DashboardInstanceMagicMcpServersListQuery
# DashboardInstanceMagicMcpServersUpdateBody
# DashboardInstanceMagicMcpServersUpdateOutput
# DashboardInstanceMagicMcpSessionsGetOutput
# DashboardInstanceMagicMcpSessionsListOutput
# DashboardInstanceMagicMcpSessionsListQuery
# DashboardInstanceMagicMcpTokensAddGroupsBody
# DashboardInstanceMagicMcpTokensAddGroupsOutput
# DashboardInstanceMagicMcpTokensCreateBody
# DashboardInstanceMagicMcpTokensCreateOutput
# DashboardInstanceMagicMcpTokensDeleteOutput
# DashboardInstanceMagicMcpTokensGetOutput
# DashboardInstanceMagicMcpTokensListOutput
# DashboardInstanceMagicMcpTokensListQuery
# DashboardInstanceMagicMcpTokensRemoveGroupsBody
# DashboardInstanceMagicMcpTokensRemoveGroupsOutput
# DashboardInstanceMagicMcpTokensUpdateBody
# DashboardInstanceMagicMcpTokensUpdateOutput
# DashboardInstancePortalsAccessRequestsGetOutput
# DashboardInstancePortalsAccessRequestsListOutput
# DashboardInstancePortalsAccessRequestsListQuery
# DashboardInstancePortalsAccessRequestsUpdateBody
# DashboardInstancePortalsAccessRequestsUpdateOutput
# DashboardInstancePortalsAuthAppGetOutput
# DashboardInstancePortalsAuthSsoTenantsConnectionsListOutput
# DashboardInstancePortalsAuthSsoTenantsConnectionsListQuery
# DashboardInstancePortalsAuthSsoTenantsCreateBody
# DashboardInstancePortalsAuthSsoTenantsCreateOutput
# DashboardInstancePortalsAuthSsoTenantsListOutput
# DashboardInstancePortalsAuthSsoTenantsListQuery
# DashboardInstancePortalsAuthSsoTenantsSetupOutput
# DashboardInstancePortalsConsumerAccessCreateBody
# DashboardInstancePortalsConsumerAccessCreateOutput
# DashboardInstancePortalsConsumerAccessDeleteOutput
# DashboardInstancePortalsConsumerAccessGetOutput
# DashboardInstancePortalsConsumerAccessListOutput
# DashboardInstancePortalsConsumerAccessListQuery
# DashboardInstancePortalsConsumerGroupsCreateBody
# DashboardInstancePortalsConsumerGroupsCreateOutput
# DashboardInstancePortalsConsumerGroupsDeleteOutput
# DashboardInstancePortalsConsumerGroupsGetOutput
# DashboardInstancePortalsConsumerGroupsListOutput
# DashboardInstancePortalsConsumerGroupsListQuery
# DashboardInstancePortalsConsumerGroupsUpdateBody
# DashboardInstancePortalsConsumerGroupsUpdateOutput
# DashboardInstancePortalsConsumerProfilesAssignGroupsBody
# DashboardInstancePortalsConsumerProfilesAssignGroupsOutput
# DashboardInstancePortalsConsumerProfilesGetOutput
# DashboardInstancePortalsConsumerProfilesListOutput
# DashboardInstancePortalsConsumerProfilesListQuery
# DashboardInstancePortalsConsumerProfilesUnassignGroupsBody
# DashboardInstancePortalsConsumerProfilesUnassignGroupsOutput
# DashboardInstancePortalsCreateBody
# DashboardInstancePortalsCreateOutput
# DashboardInstancePortalsDeleteOutput
# DashboardInstancePortalsGetOutput
# DashboardInstancePortalsListOutput
# DashboardInstancePortalsListQuery
# DashboardInstancePortalsUpdateBody
# DashboardInstancePortalsUpdateOutput
# DashboardInstanceProviderCategoriesGetOutput
# DashboardInstanceProviderCategoriesListOutput
# DashboardInstanceProviderCategoriesListQuery
# DashboardInstanceProviderCollectionsGetOutput
# DashboardInstanceProviderCollectionsListOutput
# DashboardInstanceProviderCollectionsListQuery
# DashboardInstanceProviderDeploymentsAuthConfigsCreateBody
# DashboardInstanceProviderDeploymentsAuthConfigsCreateOutput
# DashboardInstanceProviderDeploymentsAuthConfigsDeleteOutput
# DashboardInstanceProviderDeploymentsAuthConfigsExportsCreateBody
# DashboardInstanceProviderDeploymentsAuthConfigsExportsCreateOutput
# DashboardInstanceProviderDeploymentsAuthConfigsExportsGetOutput
# DashboardInstanceProviderDeploymentsAuthConfigsExportsListOutput
# DashboardInstanceProviderDeploymentsAuthConfigsExportsListQuery
# DashboardInstanceProviderDeploymentsAuthConfigsGetOutput
# DashboardInstanceProviderDeploymentsAuthConfigsImportsCreateBody
# DashboardInstanceProviderDeploymentsAuthConfigsImportsCreateOutput
# DashboardInstanceProviderDeploymentsAuthConfigsImportsGetOutput
# DashboardInstanceProviderDeploymentsAuthConfigsImportsGetSchemaOutput
# DashboardInstanceProviderDeploymentsAuthConfigsImportsGetSchemaQuery
# DashboardInstanceProviderDeploymentsAuthConfigsImportsListOutput
# DashboardInstanceProviderDeploymentsAuthConfigsImportsListQuery
# DashboardInstanceProviderDeploymentsAuthConfigsListOutput
# DashboardInstanceProviderDeploymentsAuthConfigsListQuery
# DashboardInstanceProviderDeploymentsAuthConfigsUpdateBody
# DashboardInstanceProviderDeploymentsAuthConfigsUpdateOutput
# DashboardInstanceProviderDeploymentsAuthCredentialsCreateBody
# DashboardInstanceProviderDeploymentsAuthCredentialsCreateOutput
# DashboardInstanceProviderDeploymentsAuthCredentialsDeleteOutput
# DashboardInstanceProviderDeploymentsAuthCredentialsGetOutput
# DashboardInstanceProviderDeploymentsAuthCredentialsListOutput
# DashboardInstanceProviderDeploymentsAuthCredentialsListQuery
# DashboardInstanceProviderDeploymentsAuthCredentialsUpdateBody
# DashboardInstanceProviderDeploymentsAuthCredentialsUpdateOutput
# DashboardInstanceProviderDeploymentsConfigVaultsCreateBody
# DashboardInstanceProviderDeploymentsConfigVaultsCreateOutput
# DashboardInstanceProviderDeploymentsConfigVaultsDeleteOutput
# DashboardInstanceProviderDeploymentsConfigVaultsGetOutput
# DashboardInstanceProviderDeploymentsConfigVaultsListOutput
# DashboardInstanceProviderDeploymentsConfigVaultsListQuery
# DashboardInstanceProviderDeploymentsConfigVaultsUpdateBody
# DashboardInstanceProviderDeploymentsConfigVaultsUpdateOutput
# DashboardInstanceProviderDeploymentsConfigsCreateBody
# DashboardInstanceProviderDeploymentsConfigsCreateOutput
# DashboardInstanceProviderDeploymentsConfigsDeleteOutput
# DashboardInstanceProviderDeploymentsConfigsGetConfigSchemaOutput
# DashboardInstanceProviderDeploymentsConfigsGetConfigSchemaQuery
# DashboardInstanceProviderDeploymentsConfigsGetOutput
# DashboardInstanceProviderDeploymentsConfigsListOutput
# DashboardInstanceProviderDeploymentsConfigsListQuery
# DashboardInstanceProviderDeploymentsConfigsUpdateBody
# DashboardInstanceProviderDeploymentsConfigsUpdateOutput
# DashboardInstanceProviderDeploymentsCreateBody
# DashboardInstanceProviderDeploymentsCreateOutput
# DashboardInstanceProviderDeploymentsDeleteOutput
# DashboardInstanceProviderDeploymentsGetOutput
# DashboardInstanceProviderDeploymentsListOutput
# DashboardInstanceProviderDeploymentsListQuery
# DashboardInstanceProviderDeploymentsSetupSessionsCreateBody
# DashboardInstanceProviderDeploymentsSetupSessionsCreateOutput
# DashboardInstanceProviderDeploymentsSetupSessionsDeleteOutput
# DashboardInstanceProviderDeploymentsSetupSessionsGetOutput
# DashboardInstanceProviderDeploymentsSetupSessionsListOutput
# DashboardInstanceProviderDeploymentsSetupSessionsListQuery
# DashboardInstanceProviderDeploymentsSetupSessionsUpdateBody
# DashboardInstanceProviderDeploymentsSetupSessionsUpdateOutput
# DashboardInstanceProviderDeploymentsUpdateBody
# DashboardInstanceProviderDeploymentsUpdateOutput
# DashboardInstanceProviderGroupsAddListingBody
# DashboardInstanceProviderGroupsAddListingOutput
# DashboardInstanceProviderGroupsCreateBody
# DashboardInstanceProviderGroupsCreateOutput
# DashboardInstanceProviderGroupsGetOutput
# DashboardInstanceProviderGroupsListOutput
# DashboardInstanceProviderGroupsListQuery
# DashboardInstanceProviderGroupsRemoveListingOutput
# DashboardInstanceProviderGroupsUpdateBody
# DashboardInstanceProviderGroupsUpdateOutput
# DashboardInstanceProviderListingsGetOutput
# DashboardInstanceProviderListingsListOutput
# DashboardInstanceProviderListingsListQuery
# DashboardInstanceProviderRunsGetLogsOutput
# DashboardInstanceProviderRunsGetOutput
# DashboardInstanceProviderRunsListOutput
# DashboardInstanceProviderRunsListQuery
# DashboardInstanceProviderTemplatesCreateBody
# DashboardInstanceProviderTemplatesCreateOutput
# DashboardInstanceProviderTemplatesDeleteOutput
# DashboardInstanceProviderTemplatesGetOutput
# DashboardInstanceProviderTemplatesListOutput
# DashboardInstanceProviderTemplatesListQuery
# DashboardInstanceProviderTemplatesUpdateBody
# DashboardInstanceProviderTemplatesUpdateOutput
# DashboardInstanceProvidersAuthMethodsGetOutput
# DashboardInstanceProvidersAuthMethodsListOutput
# DashboardInstanceProvidersAuthMethodsListQuery
# DashboardInstanceProvidersGetOutput
# DashboardInstanceProvidersListOutput
# DashboardInstanceProvidersListQuery
# DashboardInstanceProvidersSpecificationsGetOutput
# DashboardInstanceProvidersSpecificationsListOutput
# DashboardInstanceProvidersSpecificationsListQuery
# DashboardInstanceProvidersToolsGetOutput
# DashboardInstanceProvidersToolsListOutput
# DashboardInstanceProvidersToolsListQuery
# DashboardInstanceProvidersTriggersGetOutput
# DashboardInstanceProvidersTriggersListOutput
# DashboardInstanceProvidersTriggersListQuery
# DashboardInstanceProvidersVersionsGetOutput
# DashboardInstanceProvidersVersionsListOutput
# DashboardInstanceProvidersVersionsListQuery
# DashboardInstancePublishersGetOutput
# DashboardInstancePublishersListOutput
# DashboardInstancePublishersListQuery
# DashboardInstanceScmAccountsPreviewBody
# DashboardInstanceScmAccountsPreviewOutput
# DashboardInstanceScmInstallationCreateBody
# DashboardInstanceScmInstallationCreateOutput
# DashboardInstanceScmInstallationListOutput
# DashboardInstanceScmInstallationListQuery
# DashboardInstanceScmReposCreateBody
# DashboardInstanceScmReposCreateOutput
# DashboardInstanceScmReposPreviewBody
# DashboardInstanceScmReposPreviewOutput
# DashboardInstanceSessionTemplatesCreateBody
# DashboardInstanceSessionTemplatesCreateOutput
# DashboardInstanceSessionTemplatesGetOutput
# DashboardInstanceSessionTemplatesListOutput
# DashboardInstanceSessionTemplatesListQuery
# DashboardInstanceSessionTemplatesProvidersCreateBody
# DashboardInstanceSessionTemplatesProvidersCreateOutput
# DashboardInstanceSessionTemplatesProvidersDeleteOutput
# DashboardInstanceSessionTemplatesProvidersGetOutput
# DashboardInstanceSessionTemplatesProvidersListOutput
# DashboardInstanceSessionTemplatesProvidersListQuery
# DashboardInstanceSessionTemplatesProvidersUpdateBody
# DashboardInstanceSessionTemplatesProvidersUpdateOutput
# DashboardInstanceSessionTemplatesUpdateBody
# DashboardInstanceSessionTemplatesUpdateOutput
# DashboardInstanceSessionsConnectionsGetOutput
# DashboardInstanceSessionsConnectionsListOutput
# DashboardInstanceSessionsConnectionsListQuery
# DashboardInstanceSessionsCreateBody
# DashboardInstanceSessionsCreateOutput
# DashboardInstanceSessionsErrorGroupsGetOutput
# DashboardInstanceSessionsErrorGroupsListOutput
# DashboardInstanceSessionsErrorGroupsListQuery
# DashboardInstanceSessionsErrorsGetOutput
# DashboardInstanceSessionsErrorsListOutput
# DashboardInstanceSessionsErrorsListQuery
# DashboardInstanceSessionsEventsGetOutput
# DashboardInstanceSessionsEventsListOutput
# DashboardInstanceSessionsEventsListQuery
# DashboardInstanceSessionsGetOutput
# DashboardInstanceSessionsListOutput
# DashboardInstanceSessionsListQuery
# DashboardInstanceSessionsMessagesGetOutput
# DashboardInstanceSessionsMessagesListOutput
# DashboardInstanceSessionsMessagesListQuery
# DashboardInstanceSessionsParticipantsGetOutput
# DashboardInstanceSessionsParticipantsListOutput
# DashboardInstanceSessionsParticipantsListQuery
# DashboardInstanceSessionsProvidersCreateBody
# DashboardInstanceSessionsProvidersCreateOutput
# DashboardInstanceSessionsProvidersDeleteOutput
# DashboardInstanceSessionsProvidersGetOutput
# DashboardInstanceSessionsProvidersListOutput
# DashboardInstanceSessionsProvidersListQuery
# DashboardInstanceSessionsProvidersUpdateBody
# DashboardInstanceSessionsProvidersUpdateOutput
# DashboardInstanceSessionsUpdateBody
# DashboardInstanceSessionsUpdateOutput
# DashboardInstanceToolCallsCreateBody
# DashboardInstanceToolCallsCreateOutput
# DashboardInstanceToolCallsGetOutput
# DashboardInstanceToolCallsListOutput
# DashboardInstanceToolCallsListQuery
# DashboardOauthAuthorizationRequestsApproveBody
# DashboardOauthAuthorizationRequestsApproveOutput
# DashboardOauthAuthorizationRequestsGetOutput
# DashboardOauthAuthorizationRequestsRejectBody
# DashboardOauthAuthorizationRequestsRejectOutput
# DashboardOrganizationsAccessPoliciesCreateBody
# DashboardOrganizationsAccessPoliciesCreateOutput
# DashboardOrganizationsAccessPoliciesDeleteOutput
# DashboardOrganizationsAccessPoliciesGetOutput
# DashboardOrganizationsAccessPoliciesListOutput
# DashboardOrganizationsAccessPoliciesListQuery
# DashboardOrganizationsAccessPoliciesUpdateBody
# DashboardOrganizationsAccessPoliciesUpdateOutput
# DashboardOrganizationsAccessPoliciesVersionsOutput
# DashboardOrganizationsAccessPoliciesVersionsQuery
# DashboardOrganizationsAccessRolesCreateBody
# DashboardOrganizationsAccessRolesCreateOutput
# DashboardOrganizationsAccessRolesDeleteOutput
# DashboardOrganizationsAccessRolesGetOutput
# DashboardOrganizationsAccessRolesListOutput
# DashboardOrganizationsAccessRolesListQuery
# DashboardOrganizationsAccessRolesUpdateBody
# DashboardOrganizationsAccessRolesUpdateOutput
# DashboardOrganizationsAccessRolesVersionsOutput
# DashboardOrganizationsAccessRolesVersionsQuery
# DashboardOrganizationsCreateBody
# DashboardOrganizationsCreateOutput
# DashboardOrganizationsDeleteOutput
# DashboardOrganizationsGetOutput
# DashboardOrganizationsInstancesCreateBody
# DashboardOrganizationsInstancesCreateOutput
# DashboardOrganizationsInstancesDeleteOutput
# DashboardOrganizationsInstancesGetOutput
# DashboardOrganizationsInstancesListOutput
# DashboardOrganizationsInstancesListQuery
# DashboardOrganizationsInstancesUpdateBody
# DashboardOrganizationsInstancesUpdateOutput
# DashboardOrganizationsInvitesCreateBody
# DashboardOrganizationsInvitesCreateOutput
# DashboardOrganizationsInvitesDeleteOutput
# DashboardOrganizationsInvitesEnsureLinkOutput
# DashboardOrganizationsInvitesGetOutput
# DashboardOrganizationsInvitesListOutput
# DashboardOrganizationsInvitesListQuery
# DashboardOrganizationsInvitesUpdateBody
# DashboardOrganizationsInvitesUpdateOutput
# DashboardOrganizationsJoinAcceptBody
# DashboardOrganizationsJoinAcceptOutput
# DashboardOrganizationsJoinGetOutput
# DashboardOrganizationsJoinGetQuery
# DashboardOrganizationsJoinRejectBody
# DashboardOrganizationsJoinRejectOutput
# DashboardOrganizationsListOutput
# DashboardOrganizationsListQuery
# DashboardOrganizationsMembersDeleteOutput
# DashboardOrganizationsMembersGetOutput
# DashboardOrganizationsMembersListOutput
# DashboardOrganizationsMembersListQuery
# DashboardOrganizationsMembersPoliciesCreateBody
# DashboardOrganizationsMembersPoliciesCreateOutput
# DashboardOrganizationsMembersPoliciesDeleteOutput
# DashboardOrganizationsMembersUpdateBody
# DashboardOrganizationsMembersUpdateOutput
# DashboardOrganizationsOauthAppsClientSecretsCreateOutput
# DashboardOrganizationsOauthAppsClientSecretsDeleteOutput
# DashboardOrganizationsOauthAppsCreateBody
# DashboardOrganizationsOauthAppsCreateOutput
# DashboardOrganizationsOauthAppsDeleteOutput
# DashboardOrganizationsOauthAppsGetOutput
# DashboardOrganizationsOauthAppsListOutput
# DashboardOrganizationsOauthAppsListQuery
# DashboardOrganizationsOauthAppsUpdateBody
# DashboardOrganizationsOauthAppsUpdateOutput
# DashboardOrganizationsOauthAuthorizationLogsListOutput
# DashboardOrganizationsOauthAuthorizationLogsListQuery
# DashboardOrganizationsOauthAuthorizationsGetOutput
# DashboardOrganizationsOauthAuthorizationsListOutput
# DashboardOrganizationsOauthAuthorizationsListQuery
# DashboardOrganizationsOauthAuthorizationsRevokeOutput
# DashboardOrganizationsOauthCliDevicesGetOutput
# DashboardOrganizationsOauthCliDevicesListOutput
# DashboardOrganizationsOauthCliDevicesListQuery
# DashboardOrganizationsOauthInstallationsGetOutput
# DashboardOrganizationsOauthInstallationsListOutput
# DashboardOrganizationsOauthInstallationsListQuery
# DashboardOrganizationsOauthInstallationsRevokeOutput
# DashboardOrganizationsOauthScopesListOutput
# DashboardOrganizationsProjectsBrandingGetOutput
# DashboardOrganizationsProjectsBrandingUpdateBody
# DashboardOrganizationsProjectsBrandingUpdateOutput
# DashboardOrganizationsProjectsCreateBody
# DashboardOrganizationsProjectsCreateOutput
# DashboardOrganizationsProjectsDeleteOutput
# DashboardOrganizationsProjectsGetOutput
# DashboardOrganizationsProjectsListOutput
# DashboardOrganizationsProjectsListQuery
# DashboardOrganizationsProjectsUpdateBody
# DashboardOrganizationsProjectsUpdateOutput
# DashboardOrganizationsServiceAccountsClientSecretsCreateOutput
# DashboardOrganizationsServiceAccountsClientSecretsDeleteOutput
# DashboardOrganizationsServiceAccountsCreateBody
# DashboardOrganizationsServiceAccountsCreateOutput
# DashboardOrganizationsServiceAccountsCredentialsGetOutput
# DashboardOrganizationsServiceAccountsCredentialsListOutput
# DashboardOrganizationsServiceAccountsCredentialsListQuery
# DashboardOrganizationsServiceAccountsDeleteOutput
# DashboardOrganizationsServiceAccountsGetOutput
# DashboardOrganizationsServiceAccountsListOutput
# DashboardOrganizationsServiceAccountsListQuery
# DashboardOrganizationsServiceAccountsPoliciesCreateBody
# DashboardOrganizationsServiceAccountsPoliciesCreateOutput
# DashboardOrganizationsServiceAccountsPoliciesDeleteOutput
# DashboardOrganizationsServiceAccountsUpdateBody
# DashboardOrganizationsServiceAccountsUpdateOutput
# DashboardOrganizationsTeamsCreateBody
# DashboardOrganizationsTeamsCreateOutput
# DashboardOrganizationsTeamsGetOutput
# DashboardOrganizationsTeamsListOutput
# DashboardOrganizationsTeamsListQuery
# DashboardOrganizationsTeamsMembersCreateBody
# DashboardOrganizationsTeamsMembersCreateOutput
# DashboardOrganizationsTeamsMembersDeleteOutput
# DashboardOrganizationsTeamsPoliciesCreateBody
# DashboardOrganizationsTeamsPoliciesCreateOutput
# DashboardOrganizationsTeamsPoliciesDeleteOutput
# DashboardOrganizationsTeamsUpdateBody
# DashboardOrganizationsTeamsUpdateOutput
# DashboardOrganizationsUpdateBody
# DashboardOrganizationsUpdateOutput
# DashboardUsageTimelineOutput
# DashboardUsageTimelineQuery
# ManagementOrganizationGetOutput
# ManagementOrganizationUpdateBody
# ManagementOrganizationUpdateOutput
# ManagementUserDeleteBody
# ManagementUserDeleteOutput
# ManagementUserGetOutput
# ManagementUserUpdateBody
# ManagementUserUpdateOutput
# OrganizationsFlagsGetOutput
# OrganizationsProfileGetOutput
# OrganizationsProfileUpdateBody
# OrganizationsProfileUpdateOutput

# Mapper classes
# mapApiKeysCreateBody
# mapApiKeysCreateOutput
# mapApiKeysGetOutput
# mapApiKeysListOutput
# mapApiKeysListQuery
# mapApiKeysRevealOutput
# mapApiKeysRevokeOutput
# mapApiKeysRotateBody
# mapApiKeysRotateOutput
# mapApiKeysUpdateBody
# mapApiKeysUpdateOutput
# mapDashboardBootBody
# mapDashboardBootOutput
# mapDashboardInstanceCallbacksCreateBody
# mapDashboardInstanceCallbacksCreateOutput
# mapDashboardInstanceCallbacksDeleteOutput
# mapDashboardInstanceCallbacksDestinationsCreateBody
# mapDashboardInstanceCallbacksDestinationsCreateOutput
# mapDashboardInstanceCallbacksDestinationsDeleteOutput
# mapDashboardInstanceCallbacksDestinationsGetOutput
# mapDashboardInstanceCallbacksDestinationsListOutput
# mapDashboardInstanceCallbacksDestinationsListQuery
# mapDashboardInstanceCallbacksDestinationsUpdateBody
# mapDashboardInstanceCallbacksDestinationsUpdateOutput
# mapDashboardInstanceCallbacksEventsGetOutput
# mapDashboardInstanceCallbacksEventsListOutput
# mapDashboardInstanceCallbacksEventsListQuery
# mapDashboardInstanceCallbacksGetOutput
# mapDashboardInstanceCallbacksInstancesCreateBody
# mapDashboardInstanceCallbacksInstancesCreateOutput
# mapDashboardInstanceCallbacksInstancesDeleteOutput
# mapDashboardInstanceCallbacksInstancesListOutput
# mapDashboardInstanceCallbacksInstancesListQuery
# mapDashboardInstanceCallbacksListOutput
# mapDashboardInstanceCallbacksListQuery
# mapDashboardInstanceCallbacksNotificationsGetOutput
# mapDashboardInstanceCallbacksNotificationsListOutput
# mapDashboardInstanceCallbacksNotificationsListQuery
# mapDashboardInstanceCallbacksUpdateBody
# mapDashboardInstanceCallbacksUpdateOutput
# mapDashboardInstanceCustomProvidersCodeGetCodeEditorTokenOutput
# mapDashboardInstanceCustomProvidersCommitsCreateBody
# mapDashboardInstanceCustomProvidersCommitsCreateOutput
# mapDashboardInstanceCustomProvidersCommitsGetOutput
# mapDashboardInstanceCustomProvidersCommitsListOutput
# mapDashboardInstanceCustomProvidersCommitsListQuery
# mapDashboardInstanceCustomProvidersCreateBody
# mapDashboardInstanceCustomProvidersCreateOutput
# mapDashboardInstanceCustomProvidersDeploymentsGetLogsOutput
# mapDashboardInstanceCustomProvidersDeploymentsGetOutput
# mapDashboardInstanceCustomProvidersDeploymentsListOutput
# mapDashboardInstanceCustomProvidersDeploymentsListQuery
# mapDashboardInstanceCustomProvidersEnvironmentsGetOutput
# mapDashboardInstanceCustomProvidersEnvironmentsListOutput
# mapDashboardInstanceCustomProvidersEnvironmentsListQuery
# mapDashboardInstanceCustomProvidersGetOutput
# mapDashboardInstanceCustomProvidersListOutput
# mapDashboardInstanceCustomProvidersListQuery
# mapDashboardInstanceCustomProvidersUpdateBody
# mapDashboardInstanceCustomProvidersUpdateOutput
# mapDashboardInstanceCustomProvidersVersionsCreateBody
# mapDashboardInstanceCustomProvidersVersionsCreateOutput
# mapDashboardInstanceCustomProvidersVersionsGetOutput
# mapDashboardInstanceCustomProvidersVersionsListOutput
# mapDashboardInstanceCustomProvidersVersionsListQuery
# mapDashboardInstanceFileLinksCreateBody
# mapDashboardInstanceFileLinksCreateOutput
# mapDashboardInstanceFileLinksDeleteOutput
# mapDashboardInstanceFileLinksGetOutput
# mapDashboardInstanceFileLinksListOutput
# mapDashboardInstanceFileLinksListQuery
# mapDashboardInstanceFilesDeleteOutput
# mapDashboardInstanceFilesGetOutput
# mapDashboardInstanceFilesListOutput
# mapDashboardInstanceFilesListQuery
# mapDashboardInstanceIdentitiesCreateBody
# mapDashboardInstanceIdentitiesCreateOutput
# mapDashboardInstanceIdentitiesCredentialsCreateBody
# mapDashboardInstanceIdentitiesCredentialsCreateOutput
# mapDashboardInstanceIdentitiesCredentialsDeleteOutput
# mapDashboardInstanceIdentitiesCredentialsGetOutput
# mapDashboardInstanceIdentitiesCredentialsListOutput
# mapDashboardInstanceIdentitiesCredentialsListQuery
# mapDashboardInstanceIdentitiesCredentialsUpdateBody
# mapDashboardInstanceIdentitiesCredentialsUpdateOutput
# mapDashboardInstanceIdentitiesDelegationConfigsCreateBody
# mapDashboardInstanceIdentitiesDelegationConfigsCreateOutput
# mapDashboardInstanceIdentitiesDelegationConfigsDeleteOutput
# mapDashboardInstanceIdentitiesDelegationConfigsGetOutput
# mapDashboardInstanceIdentitiesDelegationConfigsListOutput
# mapDashboardInstanceIdentitiesDelegationConfigsListQuery
# mapDashboardInstanceIdentitiesDelegationConfigsUpdateBody
# mapDashboardInstanceIdentitiesDelegationConfigsUpdateOutput
# mapDashboardInstanceIdentitiesDelegationRequestsApproveOutput
# mapDashboardInstanceIdentitiesDelegationRequestsApproveQuery
# mapDashboardInstanceIdentitiesDelegationRequestsCreateBody
# mapDashboardInstanceIdentitiesDelegationRequestsCreateOutput
# mapDashboardInstanceIdentitiesDelegationRequestsDenyOutput
# mapDashboardInstanceIdentitiesDelegationRequestsDenyQuery
# mapDashboardInstanceIdentitiesDelegationRequestsGetOutput
# mapDashboardInstanceIdentitiesDelegationRequestsGetQuery
# mapDashboardInstanceIdentitiesDelegationRequestsListOutput
# mapDashboardInstanceIdentitiesDelegationRequestsListQuery
# mapDashboardInstanceIdentitiesDelegationsCreateBody
# mapDashboardInstanceIdentitiesDelegationsCreateOutput
# mapDashboardInstanceIdentitiesDelegationsGetOutput
# mapDashboardInstanceIdentitiesDelegationsListOutput
# mapDashboardInstanceIdentitiesDelegationsListQuery
# mapDashboardInstanceIdentitiesDelegationsRevokeOutput
# mapDashboardInstanceIdentitiesDeleteOutput
# mapDashboardInstanceIdentitiesGetOutput
# mapDashboardInstanceIdentitiesListOutput
# mapDashboardInstanceIdentitiesListQuery
# mapDashboardInstanceIdentitiesUpdateBody
# mapDashboardInstanceIdentitiesUpdateOutput
# mapDashboardInstanceIdentityActorsCreateBody
# mapDashboardInstanceIdentityActorsCreateOutput
# mapDashboardInstanceIdentityActorsDeleteOutput
# mapDashboardInstanceIdentityActorsGetOutput
# mapDashboardInstanceIdentityActorsListOutput
# mapDashboardInstanceIdentityActorsListQuery
# mapDashboardInstanceIdentityActorsUpdateBody
# mapDashboardInstanceIdentityActorsUpdateOutput
# mapDashboardInstanceMagicMcpGroupsAddServersBody
# mapDashboardInstanceMagicMcpGroupsAddServersOutput
# mapDashboardInstanceMagicMcpGroupsCreateBody
# mapDashboardInstanceMagicMcpGroupsCreateOutput
# mapDashboardInstanceMagicMcpGroupsDeleteOutput
# mapDashboardInstanceMagicMcpGroupsGetOutput
# mapDashboardInstanceMagicMcpGroupsListOutput
# mapDashboardInstanceMagicMcpGroupsListQuery
# mapDashboardInstanceMagicMcpGroupsRemoveServersBody
# mapDashboardInstanceMagicMcpGroupsRemoveServersOutput
# mapDashboardInstanceMagicMcpGroupsUpdateBody
# mapDashboardInstanceMagicMcpGroupsUpdateOutput
# mapDashboardInstanceMagicMcpServersCreateBody
# mapDashboardInstanceMagicMcpServersCreateOutput
# mapDashboardInstanceMagicMcpServersDeleteOutput
# mapDashboardInstanceMagicMcpServersGetOutput
# mapDashboardInstanceMagicMcpServersListOutput
# mapDashboardInstanceMagicMcpServersListQuery
# mapDashboardInstanceMagicMcpServersUpdateBody
# mapDashboardInstanceMagicMcpServersUpdateOutput
# mapDashboardInstanceMagicMcpSessionsGetOutput
# mapDashboardInstanceMagicMcpSessionsListOutput
# mapDashboardInstanceMagicMcpSessionsListQuery
# mapDashboardInstanceMagicMcpTokensAddGroupsBody
# mapDashboardInstanceMagicMcpTokensAddGroupsOutput
# mapDashboardInstanceMagicMcpTokensCreateBody
# mapDashboardInstanceMagicMcpTokensCreateOutput
# mapDashboardInstanceMagicMcpTokensDeleteOutput
# mapDashboardInstanceMagicMcpTokensGetOutput
# mapDashboardInstanceMagicMcpTokensListOutput
# mapDashboardInstanceMagicMcpTokensListQuery
# mapDashboardInstanceMagicMcpTokensRemoveGroupsBody
# mapDashboardInstanceMagicMcpTokensRemoveGroupsOutput
# mapDashboardInstanceMagicMcpTokensUpdateBody
# mapDashboardInstanceMagicMcpTokensUpdateOutput
# mapDashboardInstancePortalsAccessRequestsGetOutput
# mapDashboardInstancePortalsAccessRequestsListOutput
# mapDashboardInstancePortalsAccessRequestsListQuery
# mapDashboardInstancePortalsAccessRequestsUpdateBody
# mapDashboardInstancePortalsAccessRequestsUpdateOutput
# mapDashboardInstancePortalsAuthAppGetOutput
# mapDashboardInstancePortalsAuthSsoTenantsConnectionsListOutput
# mapDashboardInstancePortalsAuthSsoTenantsConnectionsListQuery
# mapDashboardInstancePortalsAuthSsoTenantsCreateBody
# mapDashboardInstancePortalsAuthSsoTenantsCreateOutput
# mapDashboardInstancePortalsAuthSsoTenantsListOutput
# mapDashboardInstancePortalsAuthSsoTenantsListQuery
# mapDashboardInstancePortalsAuthSsoTenantsSetupOutput
# mapDashboardInstancePortalsConsumerAccessCreateBody
# mapDashboardInstancePortalsConsumerAccessCreateOutput
# mapDashboardInstancePortalsConsumerAccessDeleteOutput
# mapDashboardInstancePortalsConsumerAccessGetOutput
# mapDashboardInstancePortalsConsumerAccessListOutput
# mapDashboardInstancePortalsConsumerAccessListQuery
# mapDashboardInstancePortalsConsumerGroupsCreateBody
# mapDashboardInstancePortalsConsumerGroupsCreateOutput
# mapDashboardInstancePortalsConsumerGroupsDeleteOutput
# mapDashboardInstancePortalsConsumerGroupsGetOutput
# mapDashboardInstancePortalsConsumerGroupsListOutput
# mapDashboardInstancePortalsConsumerGroupsListQuery
# mapDashboardInstancePortalsConsumerGroupsUpdateBody
# mapDashboardInstancePortalsConsumerGroupsUpdateOutput
# mapDashboardInstancePortalsConsumerProfilesAssignGroupsBody
# mapDashboardInstancePortalsConsumerProfilesAssignGroupsOutput
# mapDashboardInstancePortalsConsumerProfilesGetOutput
# mapDashboardInstancePortalsConsumerProfilesListOutput
# mapDashboardInstancePortalsConsumerProfilesListQuery
# mapDashboardInstancePortalsConsumerProfilesUnassignGroupsBody
# mapDashboardInstancePortalsConsumerProfilesUnassignGroupsOutput
# mapDashboardInstancePortalsCreateBody
# mapDashboardInstancePortalsCreateOutput
# mapDashboardInstancePortalsDeleteOutput
# mapDashboardInstancePortalsGetOutput
# mapDashboardInstancePortalsListOutput
# mapDashboardInstancePortalsListQuery
# mapDashboardInstancePortalsUpdateBody
# mapDashboardInstancePortalsUpdateOutput
# mapDashboardInstanceProviderCategoriesGetOutput
# mapDashboardInstanceProviderCategoriesListOutput
# mapDashboardInstanceProviderCategoriesListQuery
# mapDashboardInstanceProviderCollectionsGetOutput
# mapDashboardInstanceProviderCollectionsListOutput
# mapDashboardInstanceProviderCollectionsListQuery
# mapDashboardInstanceProviderDeploymentsAuthConfigsCreateBody
# mapDashboardInstanceProviderDeploymentsAuthConfigsCreateOutput
# mapDashboardInstanceProviderDeploymentsAuthConfigsDeleteOutput
# mapDashboardInstanceProviderDeploymentsAuthConfigsExportsCreateBody
# mapDashboardInstanceProviderDeploymentsAuthConfigsExportsCreateOutput
# mapDashboardInstanceProviderDeploymentsAuthConfigsExportsGetOutput
# mapDashboardInstanceProviderDeploymentsAuthConfigsExportsListOutput
# mapDashboardInstanceProviderDeploymentsAuthConfigsExportsListQuery
# mapDashboardInstanceProviderDeploymentsAuthConfigsGetOutput
# mapDashboardInstanceProviderDeploymentsAuthConfigsImportsCreateBody
# mapDashboardInstanceProviderDeploymentsAuthConfigsImportsCreateOutput
# mapDashboardInstanceProviderDeploymentsAuthConfigsImportsGetOutput
# mapDashboardInstanceProviderDeploymentsAuthConfigsImportsGetSchemaOutput
# mapDashboardInstanceProviderDeploymentsAuthConfigsImportsGetSchemaQuery
# mapDashboardInstanceProviderDeploymentsAuthConfigsImportsListOutput
# mapDashboardInstanceProviderDeploymentsAuthConfigsImportsListQuery
# mapDashboardInstanceProviderDeploymentsAuthConfigsListOutput
# mapDashboardInstanceProviderDeploymentsAuthConfigsListQuery
# mapDashboardInstanceProviderDeploymentsAuthConfigsUpdateBody
# mapDashboardInstanceProviderDeploymentsAuthConfigsUpdateOutput
# mapDashboardInstanceProviderDeploymentsAuthCredentialsCreateBody
# mapDashboardInstanceProviderDeploymentsAuthCredentialsCreateOutput
# mapDashboardInstanceProviderDeploymentsAuthCredentialsDeleteOutput
# mapDashboardInstanceProviderDeploymentsAuthCredentialsGetOutput
# mapDashboardInstanceProviderDeploymentsAuthCredentialsListOutput
# mapDashboardInstanceProviderDeploymentsAuthCredentialsListQuery
# mapDashboardInstanceProviderDeploymentsAuthCredentialsUpdateBody
# mapDashboardInstanceProviderDeploymentsAuthCredentialsUpdateOutput
# mapDashboardInstanceProviderDeploymentsConfigVaultsCreateBody
# mapDashboardInstanceProviderDeploymentsConfigVaultsCreateOutput
# mapDashboardInstanceProviderDeploymentsConfigVaultsDeleteOutput
# mapDashboardInstanceProviderDeploymentsConfigVaultsGetOutput
# mapDashboardInstanceProviderDeploymentsConfigVaultsListOutput
# mapDashboardInstanceProviderDeploymentsConfigVaultsListQuery
# mapDashboardInstanceProviderDeploymentsConfigVaultsUpdateBody
# mapDashboardInstanceProviderDeploymentsConfigVaultsUpdateOutput
# mapDashboardInstanceProviderDeploymentsConfigsCreateBody
# mapDashboardInstanceProviderDeploymentsConfigsCreateOutput
# mapDashboardInstanceProviderDeploymentsConfigsDeleteOutput
# mapDashboardInstanceProviderDeploymentsConfigsGetConfigSchemaOutput
# mapDashboardInstanceProviderDeploymentsConfigsGetConfigSchemaQuery
# mapDashboardInstanceProviderDeploymentsConfigsGetOutput
# mapDashboardInstanceProviderDeploymentsConfigsListOutput
# mapDashboardInstanceProviderDeploymentsConfigsListQuery
# mapDashboardInstanceProviderDeploymentsConfigsUpdateBody
# mapDashboardInstanceProviderDeploymentsConfigsUpdateOutput
# mapDashboardInstanceProviderDeploymentsCreateBody
# mapDashboardInstanceProviderDeploymentsCreateOutput
# mapDashboardInstanceProviderDeploymentsDeleteOutput
# mapDashboardInstanceProviderDeploymentsGetOutput
# mapDashboardInstanceProviderDeploymentsListOutput
# mapDashboardInstanceProviderDeploymentsListQuery
# mapDashboardInstanceProviderDeploymentsSetupSessionsCreateBody
# mapDashboardInstanceProviderDeploymentsSetupSessionsCreateOutput
# mapDashboardInstanceProviderDeploymentsSetupSessionsDeleteOutput
# mapDashboardInstanceProviderDeploymentsSetupSessionsGetOutput
# mapDashboardInstanceProviderDeploymentsSetupSessionsListOutput
# mapDashboardInstanceProviderDeploymentsSetupSessionsListQuery
# mapDashboardInstanceProviderDeploymentsSetupSessionsUpdateBody
# mapDashboardInstanceProviderDeploymentsSetupSessionsUpdateOutput
# mapDashboardInstanceProviderDeploymentsUpdateBody
# mapDashboardInstanceProviderDeploymentsUpdateOutput
# mapDashboardInstanceProviderGroupsAddListingBody
# mapDashboardInstanceProviderGroupsAddListingOutput
# mapDashboardInstanceProviderGroupsCreateBody
# mapDashboardInstanceProviderGroupsCreateOutput
# mapDashboardInstanceProviderGroupsGetOutput
# mapDashboardInstanceProviderGroupsListOutput
# mapDashboardInstanceProviderGroupsListQuery
# mapDashboardInstanceProviderGroupsRemoveListingOutput
# mapDashboardInstanceProviderGroupsUpdateBody
# mapDashboardInstanceProviderGroupsUpdateOutput
# mapDashboardInstanceProviderListingsGetOutput
# mapDashboardInstanceProviderListingsListOutput
# mapDashboardInstanceProviderListingsListQuery
# mapDashboardInstanceProviderRunsGetLogsOutput
# mapDashboardInstanceProviderRunsGetOutput
# mapDashboardInstanceProviderRunsListOutput
# mapDashboardInstanceProviderRunsListQuery
# mapDashboardInstanceProviderTemplatesCreateBody
# mapDashboardInstanceProviderTemplatesCreateOutput
# mapDashboardInstanceProviderTemplatesDeleteOutput
# mapDashboardInstanceProviderTemplatesGetOutput
# mapDashboardInstanceProviderTemplatesListOutput
# mapDashboardInstanceProviderTemplatesListQuery
# mapDashboardInstanceProviderTemplatesUpdateBody
# mapDashboardInstanceProviderTemplatesUpdateOutput
# mapDashboardInstanceProvidersAuthMethodsGetOutput
# mapDashboardInstanceProvidersAuthMethodsListOutput
# mapDashboardInstanceProvidersAuthMethodsListQuery
# mapDashboardInstanceProvidersGetOutput
# mapDashboardInstanceProvidersListOutput
# mapDashboardInstanceProvidersListQuery
# mapDashboardInstanceProvidersSpecificationsGetOutput
# mapDashboardInstanceProvidersSpecificationsListOutput
# mapDashboardInstanceProvidersSpecificationsListQuery
# mapDashboardInstanceProvidersToolsGetOutput
# mapDashboardInstanceProvidersToolsListOutput
# mapDashboardInstanceProvidersToolsListQuery
# mapDashboardInstanceProvidersTriggersGetOutput
# mapDashboardInstanceProvidersTriggersListOutput
# mapDashboardInstanceProvidersTriggersListQuery
# mapDashboardInstanceProvidersVersionsGetOutput
# mapDashboardInstanceProvidersVersionsListOutput
# mapDashboardInstanceProvidersVersionsListQuery
# mapDashboardInstancePublishersGetOutput
# mapDashboardInstancePublishersListOutput
# mapDashboardInstancePublishersListQuery
# mapDashboardInstanceScmAccountsPreviewBody
# mapDashboardInstanceScmAccountsPreviewOutput
# mapDashboardInstanceScmInstallationCreateBody
# mapDashboardInstanceScmInstallationCreateOutput
# mapDashboardInstanceScmInstallationListOutput
# mapDashboardInstanceScmInstallationListQuery
# mapDashboardInstanceScmReposCreateBody
# mapDashboardInstanceScmReposCreateOutput
# mapDashboardInstanceScmReposPreviewBody
# mapDashboardInstanceScmReposPreviewOutput
# mapDashboardInstanceSessionTemplatesCreateBody
# mapDashboardInstanceSessionTemplatesCreateOutput
# mapDashboardInstanceSessionTemplatesGetOutput
# mapDashboardInstanceSessionTemplatesListOutput
# mapDashboardInstanceSessionTemplatesListQuery
# mapDashboardInstanceSessionTemplatesProvidersCreateBody
# mapDashboardInstanceSessionTemplatesProvidersCreateOutput
# mapDashboardInstanceSessionTemplatesProvidersDeleteOutput
# mapDashboardInstanceSessionTemplatesProvidersGetOutput
# mapDashboardInstanceSessionTemplatesProvidersListOutput
# mapDashboardInstanceSessionTemplatesProvidersListQuery
# mapDashboardInstanceSessionTemplatesProvidersUpdateBody
# mapDashboardInstanceSessionTemplatesProvidersUpdateOutput
# mapDashboardInstanceSessionTemplatesUpdateBody
# mapDashboardInstanceSessionTemplatesUpdateOutput
# mapDashboardInstanceSessionsConnectionsGetOutput
# mapDashboardInstanceSessionsConnectionsListOutput
# mapDashboardInstanceSessionsConnectionsListQuery
# mapDashboardInstanceSessionsCreateBody
# mapDashboardInstanceSessionsCreateOutput
# mapDashboardInstanceSessionsErrorGroupsGetOutput
# mapDashboardInstanceSessionsErrorGroupsListOutput
# mapDashboardInstanceSessionsErrorGroupsListQuery
# mapDashboardInstanceSessionsErrorsGetOutput
# mapDashboardInstanceSessionsErrorsListOutput
# mapDashboardInstanceSessionsErrorsListQuery
# mapDashboardInstanceSessionsEventsGetOutput
# mapDashboardInstanceSessionsEventsListOutput
# mapDashboardInstanceSessionsEventsListQuery
# mapDashboardInstanceSessionsGetOutput
# mapDashboardInstanceSessionsListOutput
# mapDashboardInstanceSessionsListQuery
# mapDashboardInstanceSessionsMessagesGetOutput
# mapDashboardInstanceSessionsMessagesListOutput
# mapDashboardInstanceSessionsMessagesListQuery
# mapDashboardInstanceSessionsParticipantsGetOutput
# mapDashboardInstanceSessionsParticipantsListOutput
# mapDashboardInstanceSessionsParticipantsListQuery
# mapDashboardInstanceSessionsProvidersCreateBody
# mapDashboardInstanceSessionsProvidersCreateOutput
# mapDashboardInstanceSessionsProvidersDeleteOutput
# mapDashboardInstanceSessionsProvidersGetOutput
# mapDashboardInstanceSessionsProvidersListOutput
# mapDashboardInstanceSessionsProvidersListQuery
# mapDashboardInstanceSessionsProvidersUpdateBody
# mapDashboardInstanceSessionsProvidersUpdateOutput
# mapDashboardInstanceSessionsUpdateBody
# mapDashboardInstanceSessionsUpdateOutput
# mapDashboardInstanceToolCallsCreateBody
# mapDashboardInstanceToolCallsCreateOutput
# mapDashboardInstanceToolCallsGetOutput
# mapDashboardInstanceToolCallsListOutput
# mapDashboardInstanceToolCallsListQuery
# mapDashboardOauthAuthorizationRequestsApproveBody
# mapDashboardOauthAuthorizationRequestsApproveOutput
# mapDashboardOauthAuthorizationRequestsGetOutput
# mapDashboardOauthAuthorizationRequestsRejectBody
# mapDashboardOauthAuthorizationRequestsRejectOutput
# mapDashboardOrganizationsAccessPoliciesCreateBody
# mapDashboardOrganizationsAccessPoliciesCreateOutput
# mapDashboardOrganizationsAccessPoliciesDeleteOutput
# mapDashboardOrganizationsAccessPoliciesGetOutput
# mapDashboardOrganizationsAccessPoliciesListOutput
# mapDashboardOrganizationsAccessPoliciesListQuery
# mapDashboardOrganizationsAccessPoliciesUpdateBody
# mapDashboardOrganizationsAccessPoliciesUpdateOutput
# mapDashboardOrganizationsAccessPoliciesVersionsOutput
# mapDashboardOrganizationsAccessPoliciesVersionsQuery
# mapDashboardOrganizationsAccessRolesCreateBody
# mapDashboardOrganizationsAccessRolesCreateOutput
# mapDashboardOrganizationsAccessRolesDeleteOutput
# mapDashboardOrganizationsAccessRolesGetOutput
# mapDashboardOrganizationsAccessRolesListOutput
# mapDashboardOrganizationsAccessRolesListQuery
# mapDashboardOrganizationsAccessRolesUpdateBody
# mapDashboardOrganizationsAccessRolesUpdateOutput
# mapDashboardOrganizationsAccessRolesVersionsOutput
# mapDashboardOrganizationsAccessRolesVersionsQuery
# mapDashboardOrganizationsCreateBody
# mapDashboardOrganizationsCreateOutput
# mapDashboardOrganizationsDeleteOutput
# mapDashboardOrganizationsGetOutput
# mapDashboardOrganizationsInstancesCreateBody
# mapDashboardOrganizationsInstancesCreateOutput
# mapDashboardOrganizationsInstancesDeleteOutput
# mapDashboardOrganizationsInstancesGetOutput
# mapDashboardOrganizationsInstancesListOutput
# mapDashboardOrganizationsInstancesListQuery
# mapDashboardOrganizationsInstancesUpdateBody
# mapDashboardOrganizationsInstancesUpdateOutput
# mapDashboardOrganizationsInvitesCreateBody
# mapDashboardOrganizationsInvitesCreateOutput
# mapDashboardOrganizationsInvitesDeleteOutput
# mapDashboardOrganizationsInvitesEnsureLinkOutput
# mapDashboardOrganizationsInvitesGetOutput
# mapDashboardOrganizationsInvitesListOutput
# mapDashboardOrganizationsInvitesListQuery
# mapDashboardOrganizationsInvitesUpdateBody
# mapDashboardOrganizationsInvitesUpdateOutput
# mapDashboardOrganizationsJoinAcceptBody
# mapDashboardOrganizationsJoinAcceptOutput
# mapDashboardOrganizationsJoinGetOutput
# mapDashboardOrganizationsJoinGetQuery
# mapDashboardOrganizationsJoinRejectBody
# mapDashboardOrganizationsJoinRejectOutput
# mapDashboardOrganizationsListOutput
# mapDashboardOrganizationsListQuery
# mapDashboardOrganizationsMembersDeleteOutput
# mapDashboardOrganizationsMembersGetOutput
# mapDashboardOrganizationsMembersListOutput
# mapDashboardOrganizationsMembersListQuery
# mapDashboardOrganizationsMembersPoliciesCreateBody
# mapDashboardOrganizationsMembersPoliciesCreateOutput
# mapDashboardOrganizationsMembersPoliciesDeleteOutput
# mapDashboardOrganizationsMembersUpdateBody
# mapDashboardOrganizationsMembersUpdateOutput
# mapDashboardOrganizationsOauthAppsClientSecretsCreateOutput
# mapDashboardOrganizationsOauthAppsClientSecretsDeleteOutput
# mapDashboardOrganizationsOauthAppsCreateBody
# mapDashboardOrganizationsOauthAppsCreateOutput
# mapDashboardOrganizationsOauthAppsDeleteOutput
# mapDashboardOrganizationsOauthAppsGetOutput
# mapDashboardOrganizationsOauthAppsListOutput
# mapDashboardOrganizationsOauthAppsListQuery
# mapDashboardOrganizationsOauthAppsUpdateBody
# mapDashboardOrganizationsOauthAppsUpdateOutput
# mapDashboardOrganizationsOauthAuthorizationLogsListOutput
# mapDashboardOrganizationsOauthAuthorizationLogsListQuery
# mapDashboardOrganizationsOauthAuthorizationsGetOutput
# mapDashboardOrganizationsOauthAuthorizationsListOutput
# mapDashboardOrganizationsOauthAuthorizationsListQuery
# mapDashboardOrganizationsOauthAuthorizationsRevokeOutput
# mapDashboardOrganizationsOauthCliDevicesGetOutput
# mapDashboardOrganizationsOauthCliDevicesListOutput
# mapDashboardOrganizationsOauthCliDevicesListQuery
# mapDashboardOrganizationsOauthInstallationsGetOutput
# mapDashboardOrganizationsOauthInstallationsListOutput
# mapDashboardOrganizationsOauthInstallationsListQuery
# mapDashboardOrganizationsOauthInstallationsRevokeOutput
# mapDashboardOrganizationsOauthScopesListOutput
# mapDashboardOrganizationsProjectsBrandingGetOutput
# mapDashboardOrganizationsProjectsBrandingUpdateBody
# mapDashboardOrganizationsProjectsBrandingUpdateOutput
# mapDashboardOrganizationsProjectsCreateBody
# mapDashboardOrganizationsProjectsCreateOutput
# mapDashboardOrganizationsProjectsDeleteOutput
# mapDashboardOrganizationsProjectsGetOutput
# mapDashboardOrganizationsProjectsListOutput
# mapDashboardOrganizationsProjectsListQuery
# mapDashboardOrganizationsProjectsUpdateBody
# mapDashboardOrganizationsProjectsUpdateOutput
# mapDashboardOrganizationsServiceAccountsClientSecretsCreateOutput
# mapDashboardOrganizationsServiceAccountsClientSecretsDeleteOutput
# mapDashboardOrganizationsServiceAccountsCreateBody
# mapDashboardOrganizationsServiceAccountsCreateOutput
# mapDashboardOrganizationsServiceAccountsCredentialsGetOutput
# mapDashboardOrganizationsServiceAccountsCredentialsListOutput
# mapDashboardOrganizationsServiceAccountsCredentialsListQuery
# mapDashboardOrganizationsServiceAccountsDeleteOutput
# mapDashboardOrganizationsServiceAccountsGetOutput
# mapDashboardOrganizationsServiceAccountsListOutput
# mapDashboardOrganizationsServiceAccountsListQuery
# mapDashboardOrganizationsServiceAccountsPoliciesCreateBody
# mapDashboardOrganizationsServiceAccountsPoliciesCreateOutput
# mapDashboardOrganizationsServiceAccountsPoliciesDeleteOutput
# mapDashboardOrganizationsServiceAccountsUpdateBody
# mapDashboardOrganizationsServiceAccountsUpdateOutput
# mapDashboardOrganizationsTeamsCreateBody
# mapDashboardOrganizationsTeamsCreateOutput
# mapDashboardOrganizationsTeamsGetOutput
# mapDashboardOrganizationsTeamsListOutput
# mapDashboardOrganizationsTeamsListQuery
# mapDashboardOrganizationsTeamsMembersCreateBody
# mapDashboardOrganizationsTeamsMembersCreateOutput
# mapDashboardOrganizationsTeamsMembersDeleteOutput
# mapDashboardOrganizationsTeamsPoliciesCreateBody
# mapDashboardOrganizationsTeamsPoliciesCreateOutput
# mapDashboardOrganizationsTeamsPoliciesDeleteOutput
# mapDashboardOrganizationsTeamsUpdateBody
# mapDashboardOrganizationsTeamsUpdateOutput
# mapDashboardOrganizationsUpdateBody
# mapDashboardOrganizationsUpdateOutput
# mapDashboardUsageTimelineOutput
# mapDashboardUsageTimelineQuery
# mapManagementOrganizationGetOutput
# mapManagementOrganizationUpdateBody
# mapManagementOrganizationUpdateOutput
# mapManagementUserDeleteBody
# mapManagementUserDeleteOutput
# mapManagementUserGetOutput
# mapManagementUserUpdateBody
# mapManagementUserUpdateOutput
# mapOrganizationsFlagsGetOutput
# mapOrganizationsProfileGetOutput
# mapOrganizationsProfileUpdateBody
# mapOrganizationsProfileUpdateOutput

# All types and mappers are available via:
# from .resources import *
# from .endpoints import *



from dataclasses import dataclass
from typing import Any, Dict, List, Optional, Union
from datetime import datetime
import dataclasses

@dataclass
class DashboardInstanceCallbacksEventsListOutputItems:
    object: str
    id: str
    type: str
    source_id: str
    trigger_key: str
    input: Dict[str, Any]
    output: Dict[str, Any]
    delivery_status: str
    callback_id: str
    created_at: datetime
    callback_instance_id: Optional[str] = None
@dataclass
class DashboardInstanceCallbacksEventsListOutputPagination:
    has_more_before: bool
    has_more_after: bool
@dataclass
class DashboardInstanceCallbacksEventsListOutput:
    items: List[DashboardInstanceCallbacksEventsListOutputItems]
    pagination: DashboardInstanceCallbacksEventsListOutputPagination


class mapDashboardInstanceCallbacksEventsListOutputItems:
    @staticmethod
    def from_dict(data: Dict[str, Any]) -> DashboardInstanceCallbacksEventsListOutputItems:
        return DashboardInstanceCallbacksEventsListOutputItems(
        object=data.get('object'),
        id=data.get('id'),
        type=data.get('type'),
        source_id=data.get('source_id'),
        trigger_key=data.get('trigger_key'),
        input=data.get('input'),
        output=data.get('output'),
        delivery_status=data.get('delivery_status'),
        callback_id=data.get('callback_id'),
        callback_instance_id=data.get('callback_instance_id'),
        created_at=datetime.fromisoformat(data.get('created_at').replace('Z', '+00:00')) if data.get('created_at') else None
        )

    @staticmethod
    def to_dict(value: Union[DashboardInstanceCallbacksEventsListOutputItems, Dict[str, Any], None]) -> Optional[Dict[str, Any]]:
        if value is None:
            return None
        if isinstance(value, dict):
            return value
        return dataclasses.asdict(value)

class mapDashboardInstanceCallbacksEventsListOutputPagination:
    @staticmethod
    def from_dict(data: Dict[str, Any]) -> DashboardInstanceCallbacksEventsListOutputPagination:
        return DashboardInstanceCallbacksEventsListOutputPagination(
        has_more_before=data.get('has_more_before'),
        has_more_after=data.get('has_more_after')
        )

    @staticmethod
    def to_dict(value: Union[DashboardInstanceCallbacksEventsListOutputPagination, Dict[str, Any], None]) -> Optional[Dict[str, Any]]:
        if value is None:
            return None
        if isinstance(value, dict):
            return value
        return dataclasses.asdict(value)

class mapDashboardInstanceCallbacksEventsListOutput:
    @staticmethod
    def from_dict(data: Dict[str, Any]) -> DashboardInstanceCallbacksEventsListOutput:
        return DashboardInstanceCallbacksEventsListOutput(
        items=[mapDashboardInstanceCallbacksEventsListOutputItems.from_dict(item) for item in data.get('items', []) if item],
        pagination=mapDashboardInstanceCallbacksEventsListOutputPagination.from_dict(data.get('pagination')) if data.get('pagination') else None
        )

    @staticmethod
    def to_dict(value: Union[DashboardInstanceCallbacksEventsListOutput, Dict[str, Any], None]) -> Optional[Dict[str, Any]]:
        if value is None:
            return None
        if isinstance(value, dict):
            return value
        # assume dataclass for generated models
        return dataclasses.asdict(value)

@dataclass
class DashboardInstanceCallbacksEventsListQuery:
    limit: Optional[float] = None
    after: Optional[str] = None
    before: Optional[str] = None
    cursor: Optional[str] = None
    order: Optional[str] = None
    id: Optional[Union[str, List[str]]] = None
    type: Optional[Union[str, List[str]]] = None
    source_id: Optional[Union[str, List[str]]] = None


class mapDashboardInstanceCallbacksEventsListQuery:
    @staticmethod
    def from_dict(data: Dict[str, Any]) -> DashboardInstanceCallbacksEventsListQuery:
        return DashboardInstanceCallbacksEventsListQuery(
        limit=data.get('limit'),
        after=data.get('after'),
        before=data.get('before'),
        cursor=data.get('cursor'),
        order=data.get('order'),
        id=data.get('id'),
        type=data.get('type'),
        source_id=data.get('source_id')
        )

    @staticmethod
    def to_dict(value: Union[DashboardInstanceCallbacksEventsListQuery, Dict[str, Any], None]) -> Optional[Dict[str, Any]]:
        if value is None:
            return None
        if isinstance(value, dict):
            return value
        # assume dataclass for generated models
        return dataclasses.asdict(value)




from dataclasses import dataclass
from typing import Any, Dict, List, Optional, Union
from datetime import datetime
from metorial.utils import parse_iso_datetime
import dataclasses


@dataclass
class DashboardInstanceSessionsListOutputItemsClientSecret:
  object: str
  type: str
  id: str
  secret: str
  expires_at: datetime


@dataclass
class DashboardInstanceSessionsListOutputItemsServerDeploymentsServer:
  object: str
  id: str
  name: str
  type: str
  created_at: datetime
  updated_at: datetime
  description: Optional[str] = None


@dataclass
class DashboardInstanceSessionsListOutputItemsServerDeploymentsConnectionUrls:
  sse: str
  streamable_http: str


@dataclass
class DashboardInstanceSessionsListOutputItemsServerDeployments:
  object: str
  id: str
  metadata: Dict[str, Any]
  created_at: datetime
  updated_at: datetime
  server: DashboardInstanceSessionsListOutputItemsServerDeploymentsServer
  connection_urls: DashboardInstanceSessionsListOutputItemsServerDeploymentsConnectionUrls
  name: Optional[str] = None
  oauth_session_id: Optional[str] = None
  description: Optional[str] = None


@dataclass
class DashboardInstanceSessionsListOutputItemsUsage:
  total_productive_message_count: float
  total_productive_client_message_count: float
  total_productive_server_message_count: float


@dataclass
class DashboardInstanceSessionsListOutputItems:
  object: str
  id: str
  status: str
  connection_status: str
  client_secret: DashboardInstanceSessionsListOutputItemsClientSecret
  server_deployments: List[DashboardInstanceSessionsListOutputItemsServerDeployments]
  usage: DashboardInstanceSessionsListOutputItemsUsage
  metadata: Dict[str, Any]
  created_at: datetime
  updated_at: datetime


@dataclass
class DashboardInstanceSessionsListOutputPagination:
  has_more_before: bool
  has_more_after: bool


@dataclass
class DashboardInstanceSessionsListOutput:
  items: List[DashboardInstanceSessionsListOutputItems]
  pagination: DashboardInstanceSessionsListOutputPagination


class mapDashboardInstanceSessionsListOutputItemsClientSecret:
  @staticmethod
  def from_dict(
    data: Dict[str, Any]
  ) -> DashboardInstanceSessionsListOutputItemsClientSecret:
    return DashboardInstanceSessionsListOutputItemsClientSecret(
      object=data.get("object"),
      type=data.get("type"),
      id=data.get("id"),
      secret=data.get("secret"),
      expires_at=parse_iso_datetime(data.get("expires_at"))
      if data.get("expires_at")
      else None,
    )

  @staticmethod
  def to_dict(
    value: Union[
      DashboardInstanceSessionsListOutputItemsClientSecret, Dict[str, Any], None
    ]
  ) -> Optional[Dict[str, Any]]:
    if value is None:
      return None
    if isinstance(value, dict):
      return value
    return dataclasses.asdict(value)


class mapDashboardInstanceSessionsListOutputItemsServerDeploymentsServer:
  @staticmethod
  def from_dict(
    data: Dict[str, Any]
  ) -> DashboardInstanceSessionsListOutputItemsServerDeploymentsServer:
    return DashboardInstanceSessionsListOutputItemsServerDeploymentsServer(
      object=data.get("object"),
      id=data.get("id"),
      name=data.get("name"),
      description=data.get("description"),
      type=data.get("type"),
      created_at=parse_iso_datetime(data.get("created_at"))
      if data.get("created_at")
      else None,
      updated_at=parse_iso_datetime(data.get("updated_at"))
      if data.get("updated_at")
      else None,
    )

  @staticmethod
  def to_dict(
    value: Union[
      DashboardInstanceSessionsListOutputItemsServerDeploymentsServer,
      Dict[str, Any],
      None,
    ]
  ) -> Optional[Dict[str, Any]]:
    if value is None:
      return None
    if isinstance(value, dict):
      return value
    return dataclasses.asdict(value)


class mapDashboardInstanceSessionsListOutputItemsServerDeploymentsConnectionUrls:
  @staticmethod
  def from_dict(
    data: Dict[str, Any]
  ) -> DashboardInstanceSessionsListOutputItemsServerDeploymentsConnectionUrls:
    return DashboardInstanceSessionsListOutputItemsServerDeploymentsConnectionUrls(
      sse=data.get("sse"), streamable_http=data.get("streamable_http")
    )

  @staticmethod
  def to_dict(
    value: Union[
      DashboardInstanceSessionsListOutputItemsServerDeploymentsConnectionUrls,
      Dict[str, Any],
      None,
    ]
  ) -> Optional[Dict[str, Any]]:
    if value is None:
      return None
    if isinstance(value, dict):
      return value
    return dataclasses.asdict(value)


class mapDashboardInstanceSessionsListOutputItemsServerDeployments:
  @staticmethod
  def from_dict(
    data: Dict[str, Any]
  ) -> DashboardInstanceSessionsListOutputItemsServerDeployments:
    return DashboardInstanceSessionsListOutputItemsServerDeployments(
      object=data.get("object"),
      id=data.get("id"),
      name=data.get("name"),
      oauth_session_id=data.get("oauth_session_id"),
      description=data.get("description"),
      metadata=data.get("metadata"),
      created_at=parse_iso_datetime(data.get("created_at"))
      if data.get("created_at")
      else None,
      updated_at=parse_iso_datetime(data.get("updated_at"))
      if data.get("updated_at")
      else None,
      server=mapDashboardInstanceSessionsListOutputItemsServerDeploymentsServer.from_dict(
        data.get("server")
      )
      if data.get("server")
      else None,
      connection_urls=mapDashboardInstanceSessionsListOutputItemsServerDeploymentsConnectionUrls.from_dict(
        data.get("connection_urls")
      )
      if data.get("connection_urls")
      else None,
    )

  @staticmethod
  def to_dict(
    value: Union[
      DashboardInstanceSessionsListOutputItemsServerDeployments, Dict[str, Any], None
    ]
  ) -> Optional[Dict[str, Any]]:
    if value is None:
      return None
    if isinstance(value, dict):
      return value
    return dataclasses.asdict(value)


class mapDashboardInstanceSessionsListOutputItemsUsage:
  @staticmethod
  def from_dict(data: Dict[str, Any]) -> DashboardInstanceSessionsListOutputItemsUsage:
    return DashboardInstanceSessionsListOutputItemsUsage(
      total_productive_message_count=data.get("total_productive_message_count"),
      total_productive_client_message_count=data.get(
        "total_productive_client_message_count"
      ),
      total_productive_server_message_count=data.get(
        "total_productive_server_message_count"
      ),
    )

  @staticmethod
  def to_dict(
    value: Union[DashboardInstanceSessionsListOutputItemsUsage, Dict[str, Any], None]
  ) -> Optional[Dict[str, Any]]:
    if value is None:
      return None
    if isinstance(value, dict):
      return value
    return dataclasses.asdict(value)


class mapDashboardInstanceSessionsListOutputItems:
  @staticmethod
  def from_dict(data: Dict[str, Any]) -> DashboardInstanceSessionsListOutputItems:
    return DashboardInstanceSessionsListOutputItems(
      object=data.get("object"),
      id=data.get("id"),
      status=data.get("status"),
      connection_status=data.get("connection_status"),
      client_secret=mapDashboardInstanceSessionsListOutputItemsClientSecret.from_dict(
        data.get("client_secret")
      )
      if data.get("client_secret")
      else None,
      server_deployments=[
        mapDashboardInstanceSessionsListOutputItemsServerDeployments.from_dict(item)
        for item in data.get("server_deployments", [])
        if item
      ],
      usage=mapDashboardInstanceSessionsListOutputItemsUsage.from_dict(
        data.get("usage")
      )
      if data.get("usage")
      else None,
      metadata=data.get("metadata"),
      created_at=parse_iso_datetime(data.get("created_at"))
      if data.get("created_at")
      else None,
      updated_at=parse_iso_datetime(data.get("updated_at"))
      if data.get("updated_at")
      else None,
    )

  @staticmethod
  def to_dict(
    value: Union[DashboardInstanceSessionsListOutputItems, Dict[str, Any], None]
  ) -> Optional[Dict[str, Any]]:
    if value is None:
      return None
    if isinstance(value, dict):
      return value
    return dataclasses.asdict(value)


class mapDashboardInstanceSessionsListOutputPagination:
  @staticmethod
  def from_dict(data: Dict[str, Any]) -> DashboardInstanceSessionsListOutputPagination:
    return DashboardInstanceSessionsListOutputPagination(
      has_more_before=data.get("has_more_before"),
      has_more_after=data.get("has_more_after"),
    )

  @staticmethod
  def to_dict(
    value: Union[DashboardInstanceSessionsListOutputPagination, Dict[str, Any], None]
  ) -> Optional[Dict[str, Any]]:
    if value is None:
      return None
    if isinstance(value, dict):
      return value
    return dataclasses.asdict(value)


class mapDashboardInstanceSessionsListOutput:
  @staticmethod
  def from_dict(data: Dict[str, Any]) -> DashboardInstanceSessionsListOutput:
    return DashboardInstanceSessionsListOutput(
      items=[
        mapDashboardInstanceSessionsListOutputItems.from_dict(item)
        for item in data.get("items", [])
        if item
      ],
      pagination=mapDashboardInstanceSessionsListOutputPagination.from_dict(
        data.get("pagination")
      )
      if data.get("pagination")
      else None,
    )

  @staticmethod
  def to_dict(
    value: Union[DashboardInstanceSessionsListOutput, Dict[str, Any], None]
  ) -> Optional[Dict[str, Any]]:
    if value is None:
      return None
    if isinstance(value, dict):
      return value
    # assume dataclass for generated models
    return dataclasses.asdict(value)


@dataclass
class DashboardInstanceSessionsListQuery:
  limit: Optional[float] = None
  after: Optional[str] = None
  before: Optional[str] = None
  cursor: Optional[str] = None
  order: Optional[str] = None
  status: Optional[Union[str, List[str]]] = None
  server_id: Optional[Union[str, List[str]]] = None
  server_variant_id: Optional[Union[str, List[str]]] = None
  server_implementation_id: Optional[Union[str, List[str]]] = None
  server_deployment_id: Optional[Union[str, List[str]]] = None


class mapDashboardInstanceSessionsListQuery:
  @staticmethod
  def from_dict(data: Dict[str, Any]) -> DashboardInstanceSessionsListQuery:
    return DashboardInstanceSessionsListQuery(
      limit=data.get("limit"),
      after=data.get("after"),
      before=data.get("before"),
      cursor=data.get("cursor"),
      order=data.get("order"),
      status=data.get("status"),
      server_id=data.get("server_id"),
      server_variant_id=data.get("server_variant_id"),
      server_implementation_id=data.get("server_implementation_id"),
      server_deployment_id=data.get("server_deployment_id"),
    )

  @staticmethod
  def to_dict(
    value: Union[DashboardInstanceSessionsListQuery, Dict[str, Any], None]
  ) -> Optional[Dict[str, Any]]:
    if value is None:
      return None
    if isinstance(value, dict):
      return value
    # assume dataclass for generated models
    return dataclasses.asdict(value)



from dataclasses import dataclass
from typing import Any, Dict, List, Optional, Union
from datetime import datetime
from metorial.utils import parse_iso_datetime
import dataclasses


@dataclass
class ApiKeysListOutputItemsMachineAccessActorTeams:
  id: str
  name: str
  slug: str
  assignment_id: str
  created_at: datetime
  updated_at: datetime


@dataclass
class ApiKeysListOutputItemsMachineAccessActor:
  object: str
  id: str
  type: str
  organization_id: str
  name: str
  image_url: str
  teams: List[ApiKeysListOutputItemsMachineAccessActorTeams]
  created_at: datetime
  updated_at: datetime
  email: Optional[str] = None


@dataclass
class ApiKeysListOutputItemsMachineAccessInstanceProject:
  object: str
  id: str
  status: str
  slug: str
  name: str
  organization_id: str
  created_at: datetime
  updated_at: datetime


@dataclass
class ApiKeysListOutputItemsMachineAccessInstance:
  object: str
  id: str
  status: str
  slug: str
  name: str
  type: str
  organization_id: str
  project: ApiKeysListOutputItemsMachineAccessInstanceProject
  created_at: datetime
  updated_at: datetime


@dataclass
class ApiKeysListOutputItemsMachineAccessOrganization:
  object: str
  id: str
  status: str
  type: str
  slug: str
  name: str
  organization_id: str
  image_url: str
  created_at: datetime
  updated_at: datetime


@dataclass
class ApiKeysListOutputItemsMachineAccessUser:
  object: str
  id: str
  status: str
  type: str
  email: str
  name: str
  first_name: str
  last_name: str
  image_url: str
  created_at: datetime
  updated_at: datetime


@dataclass
class ApiKeysListOutputItemsMachineAccess:
  object: str
  id: str
  status: str
  type: str
  name: str
  deleted_at: datetime
  last_used_at: datetime
  created_at: datetime
  updated_at: datetime
  actor: Optional[ApiKeysListOutputItemsMachineAccessActor] = None
  instance: Optional[ApiKeysListOutputItemsMachineAccessInstance] = None
  organization: Optional[ApiKeysListOutputItemsMachineAccessOrganization] = None
  user: Optional[ApiKeysListOutputItemsMachineAccessUser] = None


@dataclass
class ApiKeysListOutputItemsRevealInfo:
  until: datetime
  forever: bool


@dataclass
class ApiKeysListOutputItems:
  object: str
  id: str
  status: str
  secret_redacted: str
  secret_redacted_long: str
  type: str
  name: str
  machine_access: ApiKeysListOutputItemsMachineAccess
  created_at: datetime
  updated_at: datetime
  secret: Optional[str] = None
  description: Optional[str] = None
  deleted_at: Optional[datetime] = None
  last_used_at: Optional[datetime] = None
  expires_at: Optional[datetime] = None
  reveal_info: Optional[ApiKeysListOutputItemsRevealInfo] = None


@dataclass
class ApiKeysListOutputPagination:
  has_more_before: bool
  has_more_after: bool


@dataclass
class ApiKeysListOutput:
  items: List[ApiKeysListOutputItems]
  pagination: ApiKeysListOutputPagination


class mapApiKeysListOutputItemsMachineAccessActorTeams:
  @staticmethod
  def from_dict(data: Dict[str, Any]) -> ApiKeysListOutputItemsMachineAccessActorTeams:
    return ApiKeysListOutputItemsMachineAccessActorTeams(
      id=data.get("id"),
      name=data.get("name"),
      slug=data.get("slug"),
      assignment_id=data.get("assignment_id"),
      created_at=parse_iso_datetime(data.get("created_at"))
      if data.get("created_at")
      else None,
      updated_at=parse_iso_datetime(data.get("updated_at"))
      if data.get("updated_at")
      else None,
    )

  @staticmethod
  def to_dict(
    value: Union[ApiKeysListOutputItemsMachineAccessActorTeams, Dict[str, Any], None]
  ) -> Optional[Dict[str, Any]]:
    if value is None:
      return None
    if isinstance(value, dict):
      return value
    return dataclasses.asdict(value)


class mapApiKeysListOutputItemsMachineAccessActor:
  @staticmethod
  def from_dict(data: Dict[str, Any]) -> ApiKeysListOutputItemsMachineAccessActor:
    return ApiKeysListOutputItemsMachineAccessActor(
      object=data.get("object"),
      id=data.get("id"),
      type=data.get("type"),
      organization_id=data.get("organization_id"),
      name=data.get("name"),
      email=data.get("email"),
      image_url=data.get("image_url"),
      teams=[
        mapApiKeysListOutputItemsMachineAccessActorTeams.from_dict(item)
        for item in data.get("teams", [])
        if item
      ],
      created_at=parse_iso_datetime(data.get("created_at"))
      if data.get("created_at")
      else None,
      updated_at=parse_iso_datetime(data.get("updated_at"))
      if data.get("updated_at")
      else None,
    )

  @staticmethod
  def to_dict(
    value: Union[ApiKeysListOutputItemsMachineAccessActor, Dict[str, Any], None]
  ) -> Optional[Dict[str, Any]]:
    if value is None:
      return None
    if isinstance(value, dict):
      return value
    return dataclasses.asdict(value)


class mapApiKeysListOutputItemsMachineAccessInstanceProject:
  @staticmethod
  def from_dict(
    data: Dict[str, Any]
  ) -> ApiKeysListOutputItemsMachineAccessInstanceProject:
    return ApiKeysListOutputItemsMachineAccessInstanceProject(
      object=data.get("object"),
      id=data.get("id"),
      status=data.get("status"),
      slug=data.get("slug"),
      name=data.get("name"),
      organization_id=data.get("organization_id"),
      created_at=parse_iso_datetime(data.get("created_at"))
      if data.get("created_at")
      else None,
      updated_at=parse_iso_datetime(data.get("updated_at"))
      if data.get("updated_at")
      else None,
    )

  @staticmethod
  def to_dict(
    value: Union[
      ApiKeysListOutputItemsMachineAccessInstanceProject, Dict[str, Any], None
    ]
  ) -> Optional[Dict[str, Any]]:
    if value is None:
      return None
    if isinstance(value, dict):
      return value
    return dataclasses.asdict(value)


class mapApiKeysListOutputItemsMachineAccessInstance:
  @staticmethod
  def from_dict(data: Dict[str, Any]) -> ApiKeysListOutputItemsMachineAccessInstance:
    return ApiKeysListOutputItemsMachineAccessInstance(
      object=data.get("object"),
      id=data.get("id"),
      status=data.get("status"),
      slug=data.get("slug"),
      name=data.get("name"),
      type=data.get("type"),
      organization_id=data.get("organization_id"),
      project=mapApiKeysListOutputItemsMachineAccessInstanceProject.from_dict(
        data.get("project")
      )
      if data.get("project")
      else None,
      created_at=parse_iso_datetime(data.get("created_at"))
      if data.get("created_at")
      else None,
      updated_at=parse_iso_datetime(data.get("updated_at"))
      if data.get("updated_at")
      else None,
    )

  @staticmethod
  def to_dict(
    value: Union[ApiKeysListOutputItemsMachineAccessInstance, Dict[str, Any], None]
  ) -> Optional[Dict[str, Any]]:
    if value is None:
      return None
    if isinstance(value, dict):
      return value
    return dataclasses.asdict(value)


class mapApiKeysListOutputItemsMachineAccessOrganization:
  @staticmethod
  def from_dict(
    data: Dict[str, Any]
  ) -> ApiKeysListOutputItemsMachineAccessOrganization:
    return ApiKeysListOutputItemsMachineAccessOrganization(
      object=data.get("object"),
      id=data.get("id"),
      status=data.get("status"),
      type=data.get("type"),
      slug=data.get("slug"),
      name=data.get("name"),
      organization_id=data.get("organization_id"),
      image_url=data.get("image_url"),
      created_at=parse_iso_datetime(data.get("created_at"))
      if data.get("created_at")
      else None,
      updated_at=parse_iso_datetime(data.get("updated_at"))
      if data.get("updated_at")
      else None,
    )

  @staticmethod
  def to_dict(
    value: Union[ApiKeysListOutputItemsMachineAccessOrganization, Dict[str, Any], None]
  ) -> Optional[Dict[str, Any]]:
    if value is None:
      return None
    if isinstance(value, dict):
      return value
    return dataclasses.asdict(value)


class mapApiKeysListOutputItemsMachineAccessUser:
  @staticmethod
  def from_dict(data: Dict[str, Any]) -> ApiKeysListOutputItemsMachineAccessUser:
    return ApiKeysListOutputItemsMachineAccessUser(
      object=data.get("object"),
      id=data.get("id"),
      status=data.get("status"),
      type=data.get("type"),
      email=data.get("email"),
      name=data.get("name"),
      first_name=data.get("first_name"),
      last_name=data.get("last_name"),
      image_url=data.get("image_url"),
      created_at=parse_iso_datetime(data.get("created_at"))
      if data.get("created_at")
      else None,
      updated_at=parse_iso_datetime(data.get("updated_at"))
      if data.get("updated_at")
      else None,
    )

  @staticmethod
  def to_dict(
    value: Union[ApiKeysListOutputItemsMachineAccessUser, Dict[str, Any], None]
  ) -> Optional[Dict[str, Any]]:
    if value is None:
      return None
    if isinstance(value, dict):
      return value
    return dataclasses.asdict(value)


class mapApiKeysListOutputItemsMachineAccess:
  @staticmethod
  def from_dict(data: Dict[str, Any]) -> ApiKeysListOutputItemsMachineAccess:
    return ApiKeysListOutputItemsMachineAccess(
      object=data.get("object"),
      id=data.get("id"),
      status=data.get("status"),
      type=data.get("type"),
      name=data.get("name"),
      actor=mapApiKeysListOutputItemsMachineAccessActor.from_dict(data.get("actor"))
      if data.get("actor")
      else None,
      instance=mapApiKeysListOutputItemsMachineAccessInstance.from_dict(
        data.get("instance")
      )
      if data.get("instance")
      else None,
      organization=mapApiKeysListOutputItemsMachineAccessOrganization.from_dict(
        data.get("organization")
      )
      if data.get("organization")
      else None,
      user=mapApiKeysListOutputItemsMachineAccessUser.from_dict(data.get("user"))
      if data.get("user")
      else None,
      deleted_at=parse_iso_datetime(data.get("deleted_at"))
      if data.get("deleted_at")
      else None,
      last_used_at=parse_iso_datetime(data.get("last_used_at"))
      if data.get("last_used_at")
      else None,
      created_at=parse_iso_datetime(data.get("created_at"))
      if data.get("created_at")
      else None,
      updated_at=parse_iso_datetime(data.get("updated_at"))
      if data.get("updated_at")
      else None,
    )

  @staticmethod
  def to_dict(
    value: Union[ApiKeysListOutputItemsMachineAccess, Dict[str, Any], None]
  ) -> Optional[Dict[str, Any]]:
    if value is None:
      return None
    if isinstance(value, dict):
      return value
    return dataclasses.asdict(value)


class mapApiKeysListOutputItemsRevealInfo:
  @staticmethod
  def from_dict(data: Dict[str, Any]) -> ApiKeysListOutputItemsRevealInfo:
    return ApiKeysListOutputItemsRevealInfo(
      until=parse_iso_datetime(data.get("until")) if data.get("until") else None,
      forever=data.get("forever"),
    )

  @staticmethod
  def to_dict(
    value: Union[ApiKeysListOutputItemsRevealInfo, Dict[str, Any], None]
  ) -> Optional[Dict[str, Any]]:
    if value is None:
      return None
    if isinstance(value, dict):
      return value
    return dataclasses.asdict(value)


class mapApiKeysListOutputItems:
  @staticmethod
  def from_dict(data: Dict[str, Any]) -> ApiKeysListOutputItems:
    return ApiKeysListOutputItems(
      object=data.get("object"),
      id=data.get("id"),
      status=data.get("status"),
      secret_redacted=data.get("secret_redacted"),
      secret_redacted_long=data.get("secret_redacted_long"),
      secret=data.get("secret"),
      type=data.get("type"),
      name=data.get("name"),
      description=data.get("description"),
      machine_access=mapApiKeysListOutputItemsMachineAccess.from_dict(
        data.get("machine_access")
      )
      if data.get("machine_access")
      else None,
      deleted_at=parse_iso_datetime(data.get("deleted_at"))
      if data.get("deleted_at")
      else None,
      last_used_at=parse_iso_datetime(data.get("last_used_at"))
      if data.get("last_used_at")
      else None,
      expires_at=parse_iso_datetime(data.get("expires_at"))
      if data.get("expires_at")
      else None,
      created_at=parse_iso_datetime(data.get("created_at"))
      if data.get("created_at")
      else None,
      updated_at=parse_iso_datetime(data.get("updated_at"))
      if data.get("updated_at")
      else None,
      reveal_info=mapApiKeysListOutputItemsRevealInfo.from_dict(data.get("reveal_info"))
      if data.get("reveal_info")
      else None,
    )

  @staticmethod
  def to_dict(
    value: Union[ApiKeysListOutputItems, Dict[str, Any], None]
  ) -> Optional[Dict[str, Any]]:
    if value is None:
      return None
    if isinstance(value, dict):
      return value
    return dataclasses.asdict(value)


class mapApiKeysListOutputPagination:
  @staticmethod
  def from_dict(data: Dict[str, Any]) -> ApiKeysListOutputPagination:
    return ApiKeysListOutputPagination(
      has_more_before=data.get("has_more_before"),
      has_more_after=data.get("has_more_after"),
    )

  @staticmethod
  def to_dict(
    value: Union[ApiKeysListOutputPagination, Dict[str, Any], None]
  ) -> Optional[Dict[str, Any]]:
    if value is None:
      return None
    if isinstance(value, dict):
      return value
    return dataclasses.asdict(value)


class mapApiKeysListOutput:
  @staticmethod
  def from_dict(data: Dict[str, Any]) -> ApiKeysListOutput:
    return ApiKeysListOutput(
      items=[
        mapApiKeysListOutputItems.from_dict(item)
        for item in data.get("items", [])
        if item
      ],
      pagination=mapApiKeysListOutputPagination.from_dict(data.get("pagination"))
      if data.get("pagination")
      else None,
    )

  @staticmethod
  def to_dict(
    value: Union[ApiKeysListOutput, Dict[str, Any], None]
  ) -> Optional[Dict[str, Any]]:
    if value is None:
      return None
    if isinstance(value, dict):
      return value
    # assume dataclass for generated models
    return dataclasses.asdict(value)


@dataclass
class ApiKeysListQuery:
  limit: Optional[float] = None
  after: Optional[str] = None
  before: Optional[str] = None
  cursor: Optional[str] = None
  order: Optional[str] = None
  type: Optional[str] = None
  instance_id: Optional[str] = None


class mapApiKeysListQuery:
  @staticmethod
  def from_dict(data: Dict[str, Any]) -> ApiKeysListQuery:
    return ApiKeysListQuery(
      limit=data.get("limit"),
      after=data.get("after"),
      before=data.get("before"),
      cursor=data.get("cursor"),
      order=data.get("order"),
      type=data.get("type"),
      instance_id=data.get("instance_id"),
    )

  @staticmethod
  def to_dict(
    value: Union[ApiKeysListQuery, Dict[str, Any], None]
  ) -> Optional[Dict[str, Any]]:
    if value is None:
      return None
    if isinstance(value, dict):
      return value
    # assume dataclass for generated models
    return dataclasses.asdict(value)



from typing import Any, Dict, List, Optional, Union
from metorial_util_endpoint import BaseMetorialEndpoint, MetorialEndpointManager, MetorialRequest
from ..resources import mapConsumerProvidersListOutput, ConsumerProvidersListOutput, mapConsumerProvidersListQuery, ConsumerProvidersListQuery, mapConsumerProvidersGetOutput, ConsumerProvidersGetOutput, mapConsumerProvidersRequestAccessOutput, ConsumerProvidersRequestAccessOutput, mapConsumerProvidersRequestAccessBody, ConsumerProvidersRequestAccessBody, mapConsumerProvidersSetupOutput, ConsumerProvidersSetupOutput, mapConsumerProvidersSetupBody, ConsumerProvidersSetupBody, mapConsumerProvidersGetSetupOutput, ConsumerProvidersGetSetupOutput, mapConsumerProvidersDeployOutput, ConsumerProvidersDeployOutput, mapConsumerProvidersDeployBody, ConsumerProvidersDeployBody

class MetorialConsumerProvidersEndpoint(BaseMetorialEndpoint):
    """Browse and configure portal providers from the consumer side."""

    def __init__(self, config: MetorialEndpointManager):
        super().__init__(config)

    def list(self, *, limit: Optional[float] = None, after: Optional[str] = None, before: Optional[str] = None, cursor: Optional[str] = None, order: Optional[str] = None, search: Optional[str] = None) -> ConsumerProvidersListOutput:
        """
    List consumer providers
    Returns the unified portal catalog with consumer availability.

    :param limit: Optional[float] (optional)
    :param after: Optional[str] (optional)
    :param before: Optional[str] (optional)
    :param cursor: Optional[str] (optional)
    :param order: Optional[str] (optional)
    :param search: Optional[str] (optional)
    :return: ConsumerProvidersListOutput
    """
        # Build query parameters from keyword arguments
        query_dict = {}
        if limit is not None:
            query_dict["limit"] = limit
        if after is not None:
            query_dict["after"] = after
        if before is not None:
            query_dict["before"] = before
        if cursor is not None:
            query_dict["cursor"] = cursor
        if order is not None:
            query_dict["order"] = order
        if search is not None:
            query_dict["search"] = search

        request = MetorialRequest(
            path=['consumer', 'providers'],
            query=query_dict
        )
        return self._get(request).transform(mapConsumerProvidersListOutput.from_dict)

    def get(self, catalog_item_id: str) -> ConsumerProvidersGetOutput:
        """
    Get consumer provider
    Returns one portal catalog item with any available setup capability data.

    :param catalog_item_id: str
    :return: ConsumerProvidersGetOutput
    """
        request = MetorialRequest(
            path=['consumer', 'providers', catalog_item_id]
        )
        return self._get(request).transform(mapConsumerProvidersGetOutput.from_dict)

    def request_access(self, catalog_item_id: str, *, message: Optional[str] = None, metadata: Optional[Dict[str, Any]] = None) -> ConsumerProvidersRequestAccessOutput:
        """
    Request consumer provider access
    Creates an access request for a portal catalog item.

    :param catalog_item_id: str
    :param message: Optional[str] (optional)
    :param metadata: Optional[Dict[str, Any]] (optional)
    :return: ConsumerProvidersRequestAccessOutput
    """
        # Build body parameters from keyword arguments
        body_dict = {}
        if message is not None:
            body_dict["message"] = message
        if metadata is not None:
            body_dict["metadata"] = metadata

        request = MetorialRequest(
            path=['consumer', 'providers', catalog_item_id, 'request-access'],
            body=body_dict
        )
        return self._post(request).transform(mapConsumerProvidersRequestAccessOutput.from_dict)

    def setup(self, catalog_item_id: str, *, provider_auth_method_id: Optional[str] = None) -> ConsumerProvidersSetupOutput:
        """
    Start consumer provider setup
    Starts an OAuth setup flow for a portal provider template.

    :param catalog_item_id: str
    :param provider_auth_method_id: Optional[str] (optional)
    :return: ConsumerProvidersSetupOutput
    """
        # Build body parameters from keyword arguments
        body_dict = {}
        if provider_auth_method_id is not None:
            body_dict["provider_auth_method_id"] = provider_auth_method_id

        request = MetorialRequest(
            path=['consumer', 'providers', catalog_item_id, 'setup'],
            body=body_dict
        )
        return self._post(request).transform(mapConsumerProvidersSetupOutput.from_dict)

    def get_setup(self, catalog_item_id: str, provider_setup_session_id: str) -> ConsumerProvidersGetSetupOutput:
        """
    Get consumer provider setup
    Reads the status of an OAuth setup flow for a portal provider template.

    :param catalog_item_id: str
    :param provider_setup_session_id: str
    :return: ConsumerProvidersGetSetupOutput
    """
        request = MetorialRequest(
            path=['consumer', 'providers', catalog_item_id, 'setup', provider_setup_session_id]
        )
        return self._get(request).transform(mapConsumerProvidersGetSetupOutput.from_dict)

    def deploy(self, catalog_item_id: str, *, name: Optional[str] = None, description: Optional[str] = None, metadata: Optional[Dict[str, Any]] = None, config: Optional[Dict[str, Any]] = None, auth: Optional[Union[Dict[str, Any], Dict[str, Any]]] = None) -> ConsumerProvidersDeployOutput:
        """
    Deploy consumer provider
    Creates an owned Magic MCP server from a portal provider template.

    :param catalog_item_id: str
    :param name: Optional[str] (optional)
    :param description: Optional[str] (optional)
    :param metadata: Optional[Dict[str, Any]] (optional)
    :param config: Optional[Dict[str, Any]] (optional)
    :param auth: Optional[Union[Dict[str, Any], Dict[str, Any]]] (optional)
    :return: ConsumerProvidersDeployOutput
    """
        # Build body parameters from keyword arguments
        body_dict = {}
        if name is not None:
            body_dict["name"] = name
        if description is not None:
            body_dict["description"] = description
        if metadata is not None:
            body_dict["metadata"] = metadata
        if config is not None:
            body_dict["config"] = config
        if auth is not None:
            body_dict["auth"] = auth

        request = MetorialRequest(
            path=['consumer', 'providers', catalog_item_id, 'deploy'],
            body=body_dict
        )
        return self._post(request).transform(mapConsumerProvidersDeployOutput.from_dict)


from typing import Any, Dict, List, Optional, Union
from metorial._endpoint import (
  BaseMetorialEndpoint,
  MetorialEndpointManager,
  MetorialRequest,
)
from ..resources import (
  mapManagementOrganizationGetOutput,
  ManagementOrganizationGetOutput,
  mapManagementOrganizationUpdateOutput,
  ManagementOrganizationUpdateOutput,
  mapManagementOrganizationUpdateBody,
  ManagementOrganizationUpdateBody,
)


class MetorialManagementOrganizationEndpoint(BaseMetorialEndpoint):
  """Read and write organization information"""

  def __init__(self, config: MetorialEndpointManager):
    super().__init__(config)

  def get(self) -> ManagementOrganizationGetOutput:
    """
    Get organization
    Get the current organization information


    :return: ManagementOrganizationGetOutput
    """
    request = MetorialRequest(path=["organization"])
    return self._get(request).transform(mapManagementOrganizationGetOutput.from_dict)

  def update(self, *, name: Optional[str] = None) -> ManagementOrganizationUpdateOutput:
    """
    Update organization
    Update the current organization information

    :param name: Optional[str] (optional)
    :return: ManagementOrganizationUpdateOutput
    """
    # Build body parameters from keyword arguments
    body_dict = {}
    if name is not None:
      body_dict["name"] = name

    request = MetorialRequest(path=["organization"], body=body_dict)
    return self._patch(request).transform(
      mapManagementOrganizationUpdateOutput.from_dict
    )



from dataclasses import dataclass
from typing import Any, Dict, List, Optional, Union
from datetime import datetime
import dataclasses

@dataclass
class ManagementInstanceProviderDeploymentsConfigVaultsCreateOutputDeployment:
    object: str
    id: str
    is_default: bool
    provider_id: str
    created_at: datetime
    updated_at: datetime
    name: Optional[str] = None
    description: Optional[str] = None
    metadata: Optional[Dict[str, Any]] = None
@dataclass
class ManagementInstanceProviderDeploymentsConfigVaultsCreateOutput:
    object: str
    id: str
    name: str
    provider_id: str
    created_at: datetime
    updated_at: datetime
    description: Optional[str] = None
    metadata: Optional[Dict[str, Any]] = None
    deployment: Optional[ManagementInstanceProviderDeploymentsConfigVaultsCreateOutputDeployment] = None


class mapManagementInstanceProviderDeploymentsConfigVaultsCreateOutputDeployment:
    @staticmethod
    def from_dict(data: Dict[str, Any]) -> ManagementInstanceProviderDeploymentsConfigVaultsCreateOutputDeployment:
        return ManagementInstanceProviderDeploymentsConfigVaultsCreateOutputDeployment(
        object=data.get('object'),
        id=data.get('id'),
        is_default=data.get('is_default'),
        name=data.get('name'),
        description=data.get('description'),
        metadata=data.get('metadata'),
        provider_id=data.get('provider_id'),
        created_at=datetime.fromisoformat(data.get('created_at').replace('Z', '+00:00')) if data.get('created_at') else None,
        updated_at=datetime.fromisoformat(data.get('updated_at').replace('Z', '+00:00')) if data.get('updated_at') else None
        )

    @staticmethod
    def to_dict(value: Union[ManagementInstanceProviderDeploymentsConfigVaultsCreateOutputDeployment, Dict[str, Any], None]) -> Optional[Dict[str, Any]]:
        if value is None:
            return None
        if isinstance(value, dict):
            return value
        return dataclasses.asdict(value)

class mapManagementInstanceProviderDeploymentsConfigVaultsCreateOutput:
    @staticmethod
    def from_dict(data: Dict[str, Any]) -> ManagementInstanceProviderDeploymentsConfigVaultsCreateOutput:
        return ManagementInstanceProviderDeploymentsConfigVaultsCreateOutput(
        object=data.get('object'),
        id=data.get('id'),
        name=data.get('name'),
        description=data.get('description'),
        metadata=data.get('metadata'),
        provider_id=data.get('provider_id'),
        deployment=mapManagementInstanceProviderDeploymentsConfigVaultsCreateOutputDeployment.from_dict(data.get('deployment')) if data.get('deployment') else None,
        created_at=datetime.fromisoformat(data.get('created_at').replace('Z', '+00:00')) if data.get('created_at') else None,
        updated_at=datetime.fromisoformat(data.get('updated_at').replace('Z', '+00:00')) if data.get('updated_at') else None
        )

    @staticmethod
    def to_dict(value: Union[ManagementInstanceProviderDeploymentsConfigVaultsCreateOutput, Dict[str, Any], None]) -> Optional[Dict[str, Any]]:
        if value is None:
            return None
        if isinstance(value, dict):
            return value
        # assume dataclass for generated models
        return dataclasses.asdict(value)

@dataclass
class ManagementInstanceProviderDeploymentsConfigVaultsCreateBody:
    provider_id: str
    name: str
    value: Dict[str, Any]
    provider_deployment_id: Optional[str] = None
    description: Optional[str] = None
    metadata: Optional[Dict[str, Any]] = None


class mapManagementInstanceProviderDeploymentsConfigVaultsCreateBody:
    @staticmethod
    def from_dict(data: Dict[str, Any]) -> ManagementInstanceProviderDeploymentsConfigVaultsCreateBody:
        return ManagementInstanceProviderDeploymentsConfigVaultsCreateBody(
        provider_id=data.get('provider_id'),
        provider_deployment_id=data.get('provider_deployment_id'),
        name=data.get('name'),
        description=data.get('description'),
        metadata=data.get('metadata'),
        value=data.get('value')
        )

    @staticmethod
    def to_dict(value: Union[ManagementInstanceProviderDeploymentsConfigVaultsCreateBody, Dict[str, Any], None]) -> Optional[Dict[str, Any]]:
        if value is None:
            return None
        if isinstance(value, dict):
            return value
        # assume dataclass for generated models
        return dataclasses.asdict(value)




from typing import Any, Dict, List, Optional, Union
from metorial._endpoint import BaseMetorialEndpoint, MetorialEndpointManager, MetorialRequest
from ..resources import mapDashboardInstanceProviderDeploymentsSetupSessionsListOutput, DashboardInstanceProviderDeploymentsSetupSessionsListOutput, mapDashboardInstanceProviderDeploymentsSetupSessionsListQuery, DashboardInstanceProviderDeploymentsSetupSessionsListQuery, mapDashboardInstanceProviderDeploymentsSetupSessionsGetOutput, DashboardInstanceProviderDeploymentsSetupSessionsGetOutput, mapDashboardInstanceProviderDeploymentsSetupSessionsCreateOutput, DashboardInstanceProviderDeploymentsSetupSessionsCreateOutput, mapDashboardInstanceProviderDeploymentsSetupSessionsCreateBody, DashboardInstanceProviderDeploymentsSetupSessionsCreateBody, mapDashboardInstanceProviderDeploymentsSetupSessionsUpdateOutput, DashboardInstanceProviderDeploymentsSetupSessionsUpdateOutput, mapDashboardInstanceProviderDeploymentsSetupSessionsUpdateBody, DashboardInstanceProviderDeploymentsSetupSessionsUpdateBody, mapDashboardInstanceProviderDeploymentsSetupSessionsDeleteOutput, DashboardInstanceProviderDeploymentsSetupSessionsDeleteOutput

class MetorialProviderDeploymentsSetupSessionsEndpoint(BaseMetorialEndpoint):
    """A setup session tracks an in-progress OAuth flow, storing state during the redirect. On success, it creates an auth config with the user's access token."""

    def __init__(self, config: MetorialEndpointManager):
        super().__init__(config)

    def list(self, *, limit: Optional[float] = None, after: Optional[str] = None, before: Optional[str] = None, cursor: Optional[str] = None, order: Optional[str] = None, id: Optional[Union[str, List[str]]] = None, provider_id: Optional[Union[str, List[str]]] = None, provider_deployment_id: Optional[Union[str, List[str]]] = None, provider_auth_method_id: Optional[Union[str, List[str]]] = None, provider_auth_config_id: Optional[Union[str, List[str]]] = None, provider_auth_credentials_id: Optional[Union[str, List[str]]] = None, status: Optional[Union[str, List[str]]] = None) -> DashboardInstanceProviderDeploymentsSetupSessionsListOutput:
        """
    List provider setup sessions
    Returns a paginated list of provider setup sessions.

    :param limit: Optional[float] (optional)
    :param after: Optional[str] (optional)
    :param before: Optional[str] (optional)
    :param cursor: Optional[str] (optional)
    :param order: Optional[str] (optional)
    :param id: Optional[Union[str, List[str]]] (optional)
    :param provider_id: Optional[Union[str, List[str]]] (optional)
    :param provider_deployment_id: Optional[Union[str, List[str]]] (optional)
    :param provider_auth_method_id: Optional[Union[str, List[str]]] (optional)
    :param provider_auth_config_id: Optional[Union[str, List[str]]] (optional)
    :param provider_auth_credentials_id: Optional[Union[str, List[str]]] (optional)
    :param status: Optional[Union[str, List[str]]] (optional)
    :return: DashboardInstanceProviderDeploymentsSetupSessionsListOutput
    """
        # Build query parameters from keyword arguments
        query_dict = {}
        if limit is not None:
            query_dict["limit"] = limit
        if after is not None:
            query_dict["after"] = after
        if before is not None:
            query_dict["before"] = before
        if cursor is not None:
            query_dict["cursor"] = cursor
        if order is not None:
            query_dict["order"] = order
        if id is not None:
            query_dict["id"] = id
        if provider_id is not None:
            query_dict["provider_id"] = provider_id
        if provider_deployment_id is not None:
            query_dict["provider_deployment_id"] = provider_deployment_id
        if provider_auth_method_id is not None:
            query_dict["provider_auth_method_id"] = provider_auth_method_id
        if provider_auth_config_id is not None:
            query_dict["provider_auth_config_id"] = provider_auth_config_id
        if provider_auth_credentials_id is not None:
            query_dict["provider_auth_credentials_id"] = provider_auth_credentials_id
        if status is not None:
            query_dict["status"] = status

        request = MetorialRequest(
            path=['provider-setup-sessions'],
            query=query_dict
        )
        return self._get(request).transform(mapDashboardInstanceProviderDeploymentsSetupSessionsListOutput.from_dict)

    def get(self, provider_setup_session_id: str) -> DashboardInstanceProviderDeploymentsSetupSessionsGetOutput:
        """
    Get provider setup session
    Retrieves a specific provider setup session by ID.

    :param provider_setup_session_id: str
    :return: DashboardInstanceProviderDeploymentsSetupSessionsGetOutput
    """
        request = MetorialRequest(
            path=['provider-setup-sessions', provider_setup_session_id]
        )
        return self._get(request).transform(mapDashboardInstanceProviderDeploymentsSetupSessionsGetOutput.from_dict)

    def create(self, *, provider_id: str, provider_deployment_id: Optional[str] = None, name: Optional[str] = None, description: Optional[str] = None, metadata: Optional[Dict[str, Any]] = None, provider_auth_method_id: Optional[str] = None, provider_auth_credentials_id: Optional[str] = None, redirect_url: Optional[str] = None) -> DashboardInstanceProviderDeploymentsSetupSessionsCreateOutput:
        """
    Create provider setup session
    Creates a new provider setup session for OAuth authentication.

    :param provider_id: str
    :param provider_deployment_id: Optional[str] (optional)
    :param name: Optional[str] (optional)
    :param description: Optional[str] (optional)
    :param metadata: Optional[Dict[str, Any]] (optional)
    :param provider_auth_method_id: Optional[str] (optional)
    :param provider_auth_credentials_id: Optional[str] (optional)
    :param redirect_url: Optional[str] (optional)
    :return: DashboardInstanceProviderDeploymentsSetupSessionsCreateOutput
    """
        # Build body parameters from keyword arguments
        body_dict = {}
        body_dict["provider_id"] = provider_id
        if provider_deployment_id is not None:
            body_dict["provider_deployment_id"] = provider_deployment_id
        if name is not None:
            body_dict["name"] = name
        if description is not None:
            body_dict["description"] = description
        if metadata is not None:
            body_dict["metadata"] = metadata
        if provider_auth_method_id is not None:
            body_dict["provider_auth_method_id"] = provider_auth_method_id
        if provider_auth_credentials_id is not None:
            body_dict["provider_auth_credentials_id"] = provider_auth_credentials_id
        if redirect_url is not None:
            body_dict["redirect_url"] = redirect_url

        request = MetorialRequest(
            path=['provider-setup-sessions'],
            body=body_dict
        )
        return self._post(request).transform(mapDashboardInstanceProviderDeploymentsSetupSessionsCreateOutput.from_dict)

    def update(self, provider_setup_session_id: str, *, name: Optional[str] = None, description: Optional[str] = None, metadata: Optional[Dict[str, Any]] = None) -> DashboardInstanceProviderDeploymentsSetupSessionsUpdateOutput:
        """
    Update provider setup session
    Updates a specific provider setup session.

    :param provider_setup_session_id: str
    :param name: Optional[str] (optional)
    :param description: Optional[str] (optional)
    :param metadata: Optional[Dict[str, Any]] (optional)
    :return: DashboardInstanceProviderDeploymentsSetupSessionsUpdateOutput
    """
        # Build body parameters from keyword arguments
        body_dict = {}
        if name is not None:
            body_dict["name"] = name
        if description is not None:
            body_dict["description"] = description
        if metadata is not None:
            body_dict["metadata"] = metadata

        request = MetorialRequest(
            path=['provider-setup-sessions', provider_setup_session_id],
            body=body_dict
        )
        return self._patch(request).transform(mapDashboardInstanceProviderDeploymentsSetupSessionsUpdateOutput.from_dict)

    def delete(self, provider_setup_session_id: str) -> DashboardInstanceProviderDeploymentsSetupSessionsDeleteOutput:
        """
    Delete provider setup session
    Deletes a provider setup session.

    :param provider_setup_session_id: str
    :return: DashboardInstanceProviderDeploymentsSetupSessionsDeleteOutput
    """
        request = MetorialRequest(
            path=['provider-setup-sessions', provider_setup_session_id]
        )
        return self._delete(request).transform(mapDashboardInstanceProviderDeploymentsSetupSessionsDeleteOutput.from_dict)